function bindArgs(e, ...n) {
  return (...t) => e(...n, ...t);
}

function isObjectLike(e) {
  return null !== e && N.test(typeof e);
}

function mapProps(e, n, t) {
  const o = {};
  for (const r in n) {
    o[r] = e(n[r], r, t);
  }
  return o;
}

function zipProps(e, n) {
  const t = {};
  let o = e.length;
  for (const r of n) {
    t[e[--o]] = r;
  }
  return t;
}

function mapPropNames(e, n, t) {
  const o = {};
  for (let r = 0; r < n.length; r++) {
    const i = n[r];
    o[i] = e(i, r, t);
  }
  return o;
}

function pluckProps(e, n) {
  const t = {};
  for (const o of e) {
    t[o] = n[o];
  }
  return t;
}

function excludeUndefinedProps(e) {
  e = {
    ...e
  };
  const n = Object.keys(e);
  for (const t of n) {
    void 0 === e[t] && delete e[t];
  }
  return e;
}

function allFieldsEqual(e, n, t) {
  for (const o of e) {
    if (n[o] !== t[o]) {
      return 0;
    }
  }
  return 1;
}

function createLazyGenerator(e, n = Map) {
  const t = new n;
  return (n, ...o) => {
    if (t.has(n)) {
      return t.get(n);
    }
    {
      const r = e(n, ...o);
      return t.set(n, r), r;
    }
  };
}

function createNameDescriptors(e) {
  return createPropDescriptors({
    name: e
  }, 1);
}

function createPropDescriptors(e, n) {
  return mapProps((e => ({
    value: e,
    configurable: 1,
    writable: !n
  })), e);
}

function createGetterDescriptors(e) {
  return mapProps((e => ({
    get: e,
    configurable: 1
  })), e);
}

function createStringTagDescriptors(e) {
  return {
    [Symbol.toStringTag]: {
      value: e,
      configurable: 1
    }
  };
}

function identityFunc(e) {
  return e;
}

function padNumber(e, n) {
  return String(n).padStart(e, "0");
}

function compareNumbers(e, n) {
  return Math.sign(e - n);
}

function clampNumber(e, n, t) {
  return Math.min(Math.max(e, n), t);
}

function clampEntity(e, n, t, o, r) {
  const i = clampNumber(n, t, o);
  if (r && n !== i) {
    throw new RangeError(numberOutOfRange(e, n, t, o));
  }
  return i;
}

function clampProp(e, n, t, o, r) {
  return clampEntity(n, getDefinedProp(e, n), t, o, r);
}

function getDefinedProp(e, n) {
  const t = e[n];
  if (void 0 === t) {
    throw new TypeError(missingField(n));
  }
  return t;
}

function divModFloor(e, n) {
  return [ Math.floor(e / n), modFloor(e, n) ];
}

function modFloor(e, n) {
  return (e % n + n) % n;
}

function divModTrunc(e, n) {
  return [ divTrunc(e, n), modTrunc(e, n) ];
}

function divTrunc(e, n) {
  return Math.trunc(e / n) || 0;
}

function modTrunc(e, n) {
  return e % n || 0;
}

function hasHalf(e) {
  return .5 === Math.abs(e % 1);
}

function givenFieldsToDayTimeNano(e, n, t) {
  let o = 0, r = 0;
  for (let i = 0; i <= n; i++) {
    const n = e[t[i]], a = R[i], s = B / a, [c, l] = divModTrunc(n, s);
    o += l * a, r += c;
  }
  const [i, a] = divModTrunc(o, B);
  return [ r + i, a ];
}

function nanoToGivenFields(e, n, t) {
  const o = {};
  for (let r = n; r >= 0; r--) {
    const n = R[r];
    o[t[r]] = divTrunc(e, n), e = modTrunc(e, n);
  }
  return o;
}

function requireObjectlike(e) {
  if (!isObjectLike(e)) {
    throw new TypeError(n);
  }
  return e;
}

function requireType(e, n, t = e) {
  if (typeof n !== e) {
    throw new TypeError(invalidEntity(t, n));
  }
  return n;
}

function requireInteger(e) {
  return requireNumberIsInteger(oe(e));
}

function requirePositiveInteger(e) {
  return requireNumberIsPositive(requireInteger(e));
}

function requireNumberIsInteger(e, n = "number") {
  if (!Number.isInteger(e)) {
    throw new RangeError(expectedInteger(n, e));
  }
  return e || 0;
}

function requireNumberIsPositive(e, n = "number") {
  if (e <= 0) {
    throw new RangeError(expectedPositive(n, e));
  }
  return e;
}

function requireNonNullish(e) {
  if (null == e) {
    throw new TypeError("Cannot be null or undefined");
  }
  return e;
}

function requirePropDefined(e, n) {
  if (null == n) {
    throw new RangeError(missingField(e));
  }
  return n;
}

function toString(n) {
  if ("symbol" == typeof n) {
    throw new TypeError(e);
  }
  return String(n);
}

function toStringViaPrimitive(e, n) {
  return isObjectLike(e) ? String(e) : ne(e, n);
}

function toBigInt(e) {
  if ("string" == typeof e) {
    return BigInt(e);
  }
  if ("bigint" != typeof e) {
    throw new TypeError(invalidBigInt(e));
  }
  return e;
}

function toNumber(e, n = "number") {
  if ("bigint" == typeof e) {
    throw new TypeError(forbiddenBigIntToNumber(n));
  }
  if (e = Number(e), !Number.isFinite(e)) {
    throw new RangeError(expectedFinite(n, e));
  }
  return e;
}

function toInteger(e, n) {
  return Math.trunc(toNumber(e, n)) || 0;
}

function toStrictInteger(e, n) {
  return requireNumberIsInteger(toNumber(e, n), n);
}

function toPositiveInteger(e, n) {
  return requireNumberIsPositive(toInteger(e, n), n);
}

function refineOverflowOptions(e) {
  return void 0 === e ? 0 : Ne(requireObjectlike(e));
}

function refineZonedFieldOptions(e, n = 0) {
  e = normalizeOptions(e);
  const t = Oe(e), o = Pe(e, n);
  return [ Ne(e), o, t ];
}

function refineEpochDisambigOptions(e) {
  return Oe(normalizeOptions(e));
}

function refineDiffOptions(e, n, t, o = 9, r = 0, i = 4) {
  n = normalizeOptions(n);
  let a = ye(n, o, r), s = parseRoundingIncInteger(n), c = be(n, i), l = Ie(n, o, r, 1);
  return null == a ? a = Math.max(t, l) : checkLargestSmallestUnit(a, l), s = refineRoundingInc(s, l, 1), 
  e && (c = (e => e < 4 ? (e + 2) % 4 : e)(c)), [ a, l, s, c ];
}

function refineRoundOptions(e, n = 6, t) {
  let o = parseRoundingIncInteger(e = normalizeUnitNameOptions(e, fe));
  const r = be(e, 7);
  let i = Ie(e, n);
  return i = requirePropDefined(fe, i), o = refineRoundingInc(o, i, void 0, t), [ i, o, r ];
}

function refineDateDisplayOptions(e) {
  return ve(normalizeOptions(e));
}

function refineTimeDisplayOptions(e, n) {
  return refineTimeDisplayTuple(normalizeOptions(e), n);
}

function refineTimeDisplayTuple(e, n = 4) {
  const t = refineSubsecDigits(e);
  return [ be(e, 4), ...refineSmallestUnitAndSubsecDigits(Ie(e, n), t) ];
}

function refineSmallestUnitAndSubsecDigits(e, n) {
  return null != e ? [ R[e], e < 4 ? 9 - 3 * e : -1 ] : [ void 0 === n ? 1 : 10 ** (9 - n), n ];
}

function parseRoundingIncInteger(e) {
  let n = e[pe];
  return void 0 === n ? 1 : toInteger(n, pe);
}

function refineRoundingInc(e, n, t, o) {
  const r = o ? B : R[n + 1];
  if (r) {
    const t = R[n];
    if (r % ((e = clampEntity(pe, e, 1, r / t - (o ? 0 : 1), 1)) * t)) {
      throw new RangeError(invalidEntity(pe, e));
    }
  } else {
    e = clampEntity(pe, e, 1, t ? 10 ** 9 : 1, 1);
  }
  return e;
}

function refineSubsecDigits(e) {
  let n = e[he];
  if (void 0 !== n) {
    if ("number" != typeof n) {
      if ("auto" === toString(n)) {
        return;
      }
      throw new RangeError(invalidEntity(he, n));
    }
    n = clampEntity(he, Math.floor(n), 0, 9, 1);
  }
  return n;
}

function normalizeOptions(e) {
  return void 0 === e ? {} : requireObjectlike(e);
}

function normalizeUnitNameOptions(e, n) {
  return "string" == typeof e ? {
    [n]: e
  } : requireObjectlike(e);
}

function copyOptions(e) {
  if (void 0 !== e) {
    if (isObjectLike(e)) {
      return Object.assign(Object.create(null), e);
    }
    throw new TypeError(n);
  }
}

function overrideOverflowOptions(e, n) {
  return e && Object.assign(Object.create(null), e, {
    overflow: ge[n]
  });
}

function refineUnitOption(e, n, t = 9, o = 0, r) {
  let i = n[e];
  if (void 0 === i) {
    return r ? o : void 0;
  }
  if (i = toString(i), "auto" === i) {
    return r ? o : null;
  }
  let a = M[i];
  if (void 0 === a && (a = le[i]), void 0 === a) {
    throw new RangeError(invalidEntity(e, i));
  }
  return clampEntity(e, a, o, t, 1), a;
}

function refineChoiceOption(e, n, t, o = 0) {
  const r = t[e];
  if (void 0 === r) {
    return o;
  }
  const i = toString(r), a = n[i];
  if (void 0 === a) {
    throw new RangeError(invalidEntity(e, i));
  }
  return a;
}

function checkLargestSmallestUnit(e, n) {
  if (n > e) {
    throw new RangeError(S);
  }
}

function createDayTimeNano(e, n) {
  let [t, o] = divModTrunc(n, B), r = e + t;
  const i = Math.sign(r);
  return i && i === -Math.sign(o) && (r -= i, o += i * B), [ r, o ];
}

function addDayTimeNanoAndNumber(e, n) {
  return createDayTimeNano(e[0], e[1] + n);
}

function addDayTimeNanos(e, n, t = 1) {
  return createDayTimeNano(e[0] + n[0] * t, e[1] + n[1] * t);
}

function diffDayTimeNanos(e, n) {
  return createDayTimeNano(n[0] - e[0], n[1] - e[1]);
}

function compareDayTimeNanos(e, n) {
  return compareNumbers(e[0], n[0]) || compareNumbers(e[1], n[1]);
}

function bigIntToDayTimeNano(e, n = 1) {
  const t = BigInt(B / n);
  return [ Number(e / t), Number(e % t) * n ];
}

function numberToDayTimeNano(e, n = 1) {
  const t = B / n, [o, r] = divModTrunc(e, t);
  return [ o, r * n ];
}

function dayTimeNanoToBigInt(e, n = 1) {
  const [t, o] = e, r = Math.floor(o / n), i = B / n;
  return BigInt(t) * BigInt(i) + BigInt(r);
}

function dayTimeNanoToNumber(e, n = 1, t) {
  const [o, r] = dayTimeNanoToNumberRemainder(e, n);
  return o + (t ? r / n : 0);
}

function dayTimeNanoToNumberRemainder(e, n) {
  const [t, o] = e, [r, i] = divModFloor(o, n);
  return [ t * (B / n) + r, i ];
}

function checkIsoYearMonthInBounds(e) {
  return clampProp(e, "isoYear", We, Ge, 1), e.isoYear === We ? clampProp(e, "isoMonth", 4, 12, 1) : e.isoYear === Ge && clampProp(e, "isoMonth", 1, 9, 1), 
  e;
}

function checkIsoDateInBounds(e) {
  return checkIsoDateTimeInBounds({
    ...e,
    ...Ae,
    isoHour: 12
  }), e;
}

function checkIsoDateTimeInBounds(e) {
  const n = clampProp(e, "isoYear", We, Ge, 1), t = n === We ? 1 : n === Ge ? -1 : 0;
  return t && checkEpochNanoInBounds(isoToEpochNano({
    ...e,
    isoDay: e.isoDay + t,
    isoNanosecond: e.isoNanosecond - t
  })), e;
}

function checkEpochNanoInBounds(e) {
  if (!e || -1 === compareDayTimeNanos(e, $e) || 1 === compareDayTimeNanos(e, xe)) {
    throw new RangeError(D);
  }
  return e;
}

function isoTimeFieldsToNano(e) {
  return givenFieldsToDayTimeNano(e, 5, Be)[1];
}

function nanoToIsoTimeAndDay(e) {
  const [n, t] = divModFloor(e, B);
  return [ nanoToGivenFields(t, 5, Be), n ];
}

function epochNanoToSec(e) {
  return dayTimeNanoToNumber(e, Z);
}

function epochNanoToMilli(e) {
  return dayTimeNanoToNumber(e, C);
}

function isoToEpochMilli(e) {
  return isoArgsToEpochMilli(e.isoYear, e.isoMonth, e.isoDay, e.isoHour, e.isoMinute, e.isoSecond, e.isoMillisecond);
}

function isoToEpochNano(e) {
  const n = isoToEpochMilli(e);
  if (void 0 !== n) {
    const [t, o] = divModTrunc(n, b);
    return [ t, o * C + (e.isoMicrosecond || 0) * E + (e.isoNanosecond || 0) ];
  }
}

function isoToEpochNanoWithOffset(e, n) {
  const [t, o] = nanoToIsoTimeAndDay(isoTimeFieldsToNano(e) - n);
  return checkEpochNanoInBounds(isoToEpochNano({
    ...e,
    isoDay: e.isoDay + o,
    ...t
  }));
}

function isoArgsToEpochSec(...e) {
  return isoArgsToEpochMilli(...e) / w;
}

function isoArgsToEpochMilli(...e) {
  const [n, t] = isoToLegacyDate(...e), o = n.getTime();
  if (!isNaN(o)) {
    return o - t * b;
  }
}

function isoToLegacyDate(e, n = 1, t = 1, o = 0, r = 0, i = 0, a = 0) {
  const s = e === We ? 1 : e === Ge ? -1 : 0, c = new Date;
  return c.setUTCHours(o, r, i, a), c.setUTCFullYear(e, n - 1, t + s), [ c, s ];
}

function epochNanoToIso(e, n) {
  let [t, o] = addDayTimeNanoAndNumber(e, n);
  o < 0 && (o += B, t -= 1);
  const [r, i] = divModFloor(o, C), [a, s] = divModFloor(i, E);
  return {
    ...epochMilliToIso(t * b + r),
    isoMicrosecond: a,
    isoNanosecond: s
  };
}

function epochMilliToIso(e) {
  const n = e < -b * Ue ? 1 : e > b * Ue ? -1 : 0, t = new Date(e + n * b);
  return zipProps(Le, [ t.getUTCFullYear(), t.getUTCMonth() + 1, t.getUTCDate() - n, t.getUTCHours(), t.getUTCMinutes(), t.getUTCSeconds(), t.getUTCMilliseconds() ]);
}

function createOptionsTransformer(e, n, t = []) {
  const o = new Set(t);
  return t => (((e, n) => {
    for (const t of n) {
      if (t in e) {
        return 1;
      }
    }
    return 0;
  })(t = ((e, n) => {
    const t = {};
    for (const o in e) {
      n.has(o) || (t[o] = e[o]);
    }
    return t;
  })(t, o), e) || Object.assign(t, n), t);
}

function isoDateFieldsToEpochNano(e, n) {
  return getSingleInstantFor(queryNativeTimeZone(n.timeZone), {
    ...Ae,
    isoHour: 12,
    ...e
  });
}

function extractEpochNano(e) {
  return e.epochNanoseconds;
}

function createFormatPrepper(e, n = createFormat) {
  const [t] = e;
  return (o, r = Fn, i, a) => {
    const s = n(o, r, t, i, a), c = s.resolvedOptions();
    return [ s, ...toEpochMillis(e, c, i, a) ];
  };
}

function createFormat(e, n, t, o, r) {
  return new He(e, t(n, o, r));
}

function toEpochMillis(e, n, t, o) {
  return [ toEpochMilli(e, n, t), void 0 !== o ? toEpochMilli(e, n, o) : void 0 ];
}

function toEpochMilli([, e, n], t, o) {
  return o.calendar && ((e, n, t) => {
    if ((t || e !== we) && e !== n) {
      throw new RangeError(f);
    }
  })(getId(o.calendar), t.calendar, n), epochNanoToMilli(e(o, t));
}

function hashIntlFormatParts(e, n) {
  const t = e.formatToParts(n), o = {};
  for (const e of t) {
    o[e.type] = e.value;
  }
  return o;
}

function refinePlainDateBag(e, n, t, o = []) {
  const r = refineCalendarFields(e, n, K, o);
  return e.dateFromFields(r, t);
}

function refinePlainYearMonthBag(e, n, t, o) {
  const r = refineCalendarFields(e, n, J, o);
  return e.yearMonthFromFields(r, t);
}

function refinePlainMonthDayBag(e, n, t, o, r = []) {
  const i = refineCalendarFields(e, t, K, r);
  return n && void 0 !== i.month && void 0 === i.monthCode && void 0 === i.year && (i.year = Un), 
  e.monthDayFromFields(i, o);
}

function refineCalendarFields(e, n, t, o = [], r = []) {
  return refineFields(n, [ ...e.fields(t), ...r ].sort(), o);
}

function refineFields(e, n, o, r = !o) {
  const i = {};
  let a, s = 0;
  for (const t of n) {
    if (t === a) {
      throw new RangeError(duplicateFields(t));
    }
    if ("constructor" === t || "__proto__" === t) {
      throw new RangeError(forbiddenField(t));
    }
    let n = e[t];
    if (void 0 !== n) {
      s = 1, wn[t] && (n = wn[t](n, t)), i[t] = n;
    } else if (o) {
      if (o.includes(t)) {
        throw new TypeError(missingField(t));
      }
      i[t] = ee[t];
    }
    a = t;
  }
  if (r && !s) {
    throw new TypeError(t);
  }
  return i;
}

function refineTimeBag(e, n) {
  return constrainIsoTimeFields(En({
    ...ee,
    ...e
  }), n);
}

function mergeCalendarFields(e, n, t, o, r = [], i = []) {
  const a = [ ...e.fields(o), ...r ].sort();
  let s = refineFields(n, a, i);
  const c = refineFields(t, a);
  return s = e.mergeFields(s, c), refineFields(s, a, []);
}

function convertToPlainMonthDay(e, n) {
  const t = refineCalendarFields(e, n, X);
  return e.monthDayFromFields(t);
}

function convertToPlainYearMonth(e, n, t) {
  const o = refineCalendarFields(e, n, _);
  return e.yearMonthFromFields(o, t);
}

function convertToIso(e, n, t, o, r) {
  n = pluckProps(t = e.fields(t), n), o = refineFields(o, r = e.fields(r), []);
  let i = e.mergeFields(n, o);
  return i = refineFields(i, [ ...t, ...r ].sort(), []), e.dateFromFields(i);
}

function refineYear(e, n) {
  let {era: t, eraYear: o, year: s} = n;
  const c = getCalendarEraOrigins(e);
  if (void 0 !== t || void 0 !== o) {
    if (void 0 === t || void 0 === o) {
      throw new TypeError(i);
    }
    if (!c) {
      throw new RangeError(r);
    }
    const e = c[t];
    if (void 0 === e) {
      throw new RangeError(invalidEra(t));
    }
    const n = eraYearToYear(o, e);
    if (void 0 !== s && s !== n) {
      throw new RangeError(a);
    }
    s = n;
  } else if (void 0 === s) {
    throw new TypeError(missingYear(c));
  }
  return s;
}

function refineMonth(e, n, t, o) {
  let {month: r, monthCode: i} = n;
  if (void 0 !== i) {
    const n = ((e, n, t, o) => {
      const r = e.o(t), [i, a] = parseMonthCode(n);
      let s = monthCodeNumberToMonth(i, a, r);
      if (a) {
        const n = getCalendarLeapMonthMeta(e);
        if (void 0 === n) {
          throw new RangeError(u);
        }
        if (n > 0) {
          if (s > n) {
            throw new RangeError(u);
          }
          if (void 0 === r) {
            if (1 === o) {
              throw new RangeError(u);
            }
            s--;
          }
        } else {
          if (s !== -n) {
            throw new RangeError(u);
          }
          if (void 0 === r && 1 === o) {
            throw new RangeError(u);
          }
        }
      }
      return s;
    })(e, i, t, o);
    if (void 0 !== r && r !== n) {
      throw new RangeError(s);
    }
    r = n, o = 1;
  } else if (void 0 === r) {
    throw new TypeError(c);
  }
  return clampEntity("month", r, 1, e.i(t), o);
}

function refineDay(e, n, t, o, r) {
  return clampProp(n, "day", 1, e.l(o, t), r);
}

function spliceFields(e, n, t, o) {
  let r = 0;
  const i = [];
  for (const e of t) {
    void 0 !== n[e] ? r = 1 : i.push(e);
  }
  if (Object.assign(e, n), r) {
    for (const n of o || i) {
      delete e[n];
    }
  }
}

function parseMonthCode(e) {
  const n = Zn.exec(e);
  if (!n) {
    throw new RangeError(invalidMonthCode(e));
  }
  return [ parseInt(n[1]), Boolean(n[2]) ];
}

function monthCodeNumberToMonth(e, n, t) {
  return e + (n || t && e >= t ? 1 : 0);
}

function monthToMonthCodeNumber(e, n) {
  return e - (n && e >= n ? 1 : 0);
}

function eraYearToYear(e, n) {
  return (n + e) * (Math.sign(n) || 1) || 0;
}

function getCalendarEraOrigins(e) {
  return Ze[getCalendarIdBase(e)];
}

function getCalendarLeapMonthMeta(e) {
  return Ye[getCalendarIdBase(e)];
}

function getCalendarIdBase(e) {
  return computeCalendarIdBase(e.id || we);
}

function computeCalendarIdBase(e) {
  return e.split("-")[0];
}

function createIntlFieldCache(e) {
  return createLazyGenerator((n => {
    const t = isoToEpochMilli(n);
    return e(t);
  }), WeakMap);
}

function createIntlYearMonthCache(e) {
  const n = e(0).year - An;
  return createLazyGenerator((t => {
    let o, r = isoArgsToEpochMilli(t - n);
    const i = [], a = [];
    do {
      r += 400 * b;
    } while ((o = e(r)).year <= t);
    do {
      r += (1 - o.day) * b, o.year === t && (i.push(r), a.push(o.month)), r -= b;
    } while ((o = e(r)).year >= t);
    return {
      u: i.reverse(),
      m: O(a.reverse())
    };
  }));
}

function parseIntlYear(e, n) {
  let t, o, r = parseInt(e.relatedYear || e.year);
  if (e.era) {
    const a = Ze[n];
    void 0 !== a && (i = (i = e.era).normalize("NFD").toLowerCase().replace(/[^a-z0-9]/g, ""), 
    t = ke[i] || i, o = r, r = eraYearToYear(o, a[t] || 0));
  }
  var i;
  return {
    era: t,
    eraYear: o,
    year: r
  };
}

function buildIntlFormat$1(e) {
  return new He(bn, {
    calendar: e,
    timeZone: Yn,
    era: "short",
    year: "numeric",
    month: "short",
    day: "numeric"
  });
}

function computeIntlDateParts(e) {
  const {year: n, month: t, day: o} = this.p(e), {m: r} = this.h(n);
  return [ n, r[t] + 1, o ];
}

function computeIntlEpochMilli(e, n = 1, t = 1) {
  return this.h(e).u[n - 1] + (t - 1) * b;
}

function computeIntlLeapMonth(e) {
  const n = queryMonthStrs(this, e), t = queryMonthStrs(this, e - 1), o = n.length;
  if (o > t.length) {
    const e = getCalendarLeapMonthMeta(this);
    if (e < 0) {
      return -e;
    }
    for (let e = 0; e < o; e++) {
      if (n[e] !== t[e]) {
        return e + 1;
      }
    }
  }
}

function computeIntlDaysInYear(e) {
  return diffEpochMilliByDay(computeIntlEpochMilli.call(this, e), computeIntlEpochMilli.call(this, e + 1));
}

function computeIntlDaysInMonth(e, n) {
  const {u: t} = this.h(e);
  let o = n + 1, r = t;
  return o > t.length && (o = 1, r = this.h(e + 1).u), diffEpochMilliByDay(t[n - 1], r[o - 1]);
}

function computeIntlMonthsInYear(e) {
  return this.h(e).u.length;
}

function queryMonthStrs(e, n) {
  return Object.keys(e.h(n).m);
}

function queryNativeTimeZone(e) {
  const n = parseOffsetNanoMaybe(e = e.toLocaleUpperCase(), 1);
  return void 0 !== n ? new FixedTimeZone(n) : jn(e);
}

function createSplitTuple(e, n) {
  return [ e, n ];
}

function computePeriod(e) {
  const n = Math.floor(e / Bn) * Bn;
  return [ n, n + Bn ];
}

function formatInstantIso(e, n, t, o) {
  const [r, i, a, s] = (e => {
    const n = refineTimeDisplayTuple(e = normalizeOptions(e));
    return [ e.timeZone, ...n ];
  })(o), c = void 0 !== r;
  return ((e, n, t, o, r, i) => {
    t = roundDayTimeNanoByInc(t, r, o, 1);
    let a = n.getOffsetNanosecondsFor(t);
    return formatIsoDateTimeFields(epochNanoToIso(t, a), i) + (e ? formatOffsetNano(roundToMinute(a)) : "Z");
  })(c, n(c ? e(r) : Yn), t.epochNanoseconds, i, a, s);
}

function formatZonedDateTimeIso(e, n, t) {
  return ((e, n, t, o, r, i, a, s, c, l) => {
    o = roundDayTimeNanoByInc(o, c, s, 1);
    const u = e(t).getOffsetNanosecondsFor(o);
    return formatIsoDateTimeFields(epochNanoToIso(o, u), l) + formatOffsetNano(roundToMinute(u), a) + ((e, n) => 1 !== n ? "[" + (2 === n ? "!" : "") + getId(e) + "]" : "")(t, i) + formatCalendar(n, r);
  })(e, n.calendar, n.timeZone, n.epochNanoseconds, ...(e => {
    e = normalizeOptions(e);
    const n = ve(e), t = refineSubsecDigits(e), o = Fe(e), r = be(e, 4), i = Ie(e, 4);
    return [ n, Me(e), o, r, ...refineSmallestUnitAndSubsecDigits(i, t) ];
  })(t));
}

function formatPlainDateTimeIso(e, n) {
  return ((e, n, t, o, r, i) => formatIsoDateTimeFields(roundDateTimeToNano(n, r, o), i) + formatCalendar(e, t))(e.calendar, e, ...(e => (e = normalizeOptions(e), 
  [ ve(e), ...refineTimeDisplayTuple(e) ]))(n));
}

function formatPlainDateIso(e, n) {
  return t = e.calendar, o = e, r = refineDateDisplayOptions(n), formatIsoDateFields(o) + formatCalendar(t, r);
  var t, o, r;
}

function formatPlainYearMonthIso(e, n) {
  return formatDateLikeIso(e.calendar, formatIsoYearMonthFields, e, refineDateDisplayOptions(n));
}

function formatPlainMonthDayIso(e, n) {
  return formatDateLikeIso(e.calendar, formatIsoMonthDayFields, e, refineDateDisplayOptions(n));
}

function formatPlainTimeIso(e, n) {
  return ((e, n, t, o) => formatIsoTimeFields(roundTimeToNano(e, t, n)[0], o))(e, ...refineTimeDisplayOptions(n));
}

function formatDurationIso(e, n) {
  const [t, o, r] = refineTimeDisplayOptions(n, 3);
  return o > 1 && (e = {
    ...e,
    ...balanceDayTimeDurationByInc(e, Math.min(getLargestDurationUnit(e), 6), o, t)
  }), ((e, n) => {
    const t = Hn(e), o = -1 === t ? negateDurationFields(e) : e, {hours: r, minutes: i} = o, [a, s] = dayTimeNanoToNumberRemainder(givenFieldsToDayTimeNano(o, 3, ie), Z), c = formatSubsecNano(s, n), l = n >= 0 || !t || c;
    return (t < 0 ? "-" : "") + "P" + formatDurationFragments({
      Y: formatNumberUnscientific(o.years),
      M: formatNumberUnscientific(o.months),
      W: formatNumberUnscientific(o.weeks),
      D: formatNumberUnscientific(o.days)
    }) + (r || i || a || l ? "T" + formatDurationFragments({
      H: formatNumberUnscientific(r),
      M: formatNumberUnscientific(i),
      S: formatNumberUnscientific(a, l) + c
    }) : "");
  })(e, r);
}

function formatDateLikeIso(e, n, t, o) {
  const r = getId(e), i = o > 1 || 0 === o && r !== we;
  return 1 === o ? r === we ? n(t) : formatIsoDateFields(t) : i ? formatIsoDateFields(t) + formatCalendarId(r, 2 === o) : n(t);
}

function formatDurationFragments(e) {
  const n = [];
  for (const t in e) {
    const o = e[t];
    o && n.push(o, t);
  }
  return n.join("");
}

function formatIsoDateTimeFields(e, n) {
  return formatIsoDateFields(e) + "T" + formatIsoTimeFields(e, n);
}

function formatIsoDateFields(e) {
  return formatIsoYearMonthFields(e) + "-" + v(e.isoDay);
}

function formatIsoYearMonthFields(e) {
  const {isoYear: n} = e;
  return (n < 0 || n > 9999 ? getSignStr(n) + padNumber(6, Math.abs(n)) : padNumber(4, n)) + "-" + v(e.isoMonth);
}

function formatIsoMonthDayFields(e) {
  return v(e.isoMonth) + "-" + v(e.isoDay);
}

function formatIsoTimeFields(e, n) {
  const t = [ v(e.isoHour), v(e.isoMinute) ];
  return -1 !== n && t.push(v(e.isoSecond) + ((e, n, t, o) => formatSubsecNano(e * C + n * E + t, o))(e.isoMillisecond, e.isoMicrosecond, e.isoNanosecond, n)), 
  t.join(":");
}

function formatOffsetNano(e, n = 0) {
  if (1 === n) {
    return "";
  }
  const [t, o] = divModFloor(Math.abs(e), Y), [r, i] = divModFloor(o, k), [a, s] = divModFloor(i, Z);
  return getSignStr(e) + v(t) + ":" + v(r) + (a || s ? ":" + v(a) + formatSubsecNano(s) : "");
}

function formatCalendar(e, n) {
  if (1 !== n) {
    const t = getId(e);
    if (n > 1 || 0 === n && t !== we) {
      return formatCalendarId(t, 2 === n);
    }
  }
  return "";
}

function formatCalendarId(e, n) {
  return "[" + (n ? "!" : "") + "u-ca=" + e + "]";
}

function formatSubsecNano(e, n) {
  let t = padNumber(9, e);
  return t = void 0 === n ? t.replace(qn, "") : t.slice(0, n), t ? "." + t : "";
}

function getSignStr(e) {
  return e < 0 ? "-" : "+";
}

function formatNumberUnscientific(e, n) {
  return e || n ? e.toLocaleString("fullwide", {
    useGrouping: 0
  }) : "";
}

function zonedEpochNanoToIso(e, n) {
  return epochNanoToIso(n, e.getOffsetNanosecondsFor(n));
}

function getMatchingInstantFor(e, n, t, o = 0, r = 0, i, a) {
  if (void 0 !== t && 1 === o && (1 === o || a)) {
    return isoToEpochNanoWithOffset(n, t);
  }
  const s = e.getPossibleInstantsFor(n);
  if (void 0 !== t && 3 !== o) {
    const e = ((e, n, t, o) => {
      const r = isoToEpochNano(n);
      o && (t = roundToMinute(t));
      for (const n of e) {
        let e = dayTimeNanoToNumber(diffDayTimeNanos(n, r));
        if (o && (e = roundToMinute(e)), e === t) {
          return n;
        }
      }
    })(s, n, t, i);
    if (void 0 !== e) {
      return e;
    }
    if (0 === o) {
      throw new RangeError(h);
    }
  }
  return a ? isoToEpochNano(n) : getSingleInstantFor(e, n, r, s);
}

function getSingleInstantFor(e, n, t = 0, o = e.getPossibleInstantsFor(n)) {
  if (1 === o.length) {
    return o[0];
  }
  if (1 === t) {
    throw new RangeError(T);
  }
  if (o.length) {
    return o[3 === t ? 1 : 0];
  }
  const r = isoToEpochNano(n), i = ((e, n) => {
    const t = e.getOffsetNanosecondsFor(addDayTimeNanoAndNumber(n, -B));
    return e.getOffsetNanosecondsFor(addDayTimeNanoAndNumber(n, B)) - t;
  })(e, r), a = i * (2 === t ? -1 : 1);
  return (o = e.getPossibleInstantsFor(epochNanoToIso(r, a)))[2 === t ? 0 : o.length - 1];
}

function computeNanosecondsInDay(e, n) {
  n = {
    ...n,
    ...Ae
  };
  const t = dayTimeNanoToNumber(diffDayTimeNanos(getSingleInstantFor(e, {
    ...n,
    ...Ae
  }), getSingleInstantFor(e, {
    ...moveByIsoDays(n, 1),
    ...Ae
  })));
  if (t <= 0) {
    throw new RangeError(d);
  }
  return t;
}

function validateTimeZoneOffset(e) {
  if (Math.abs(e) >= B) {
    throw new RangeError(p);
  }
  return e;
}

function totalDayTimeNano(e, n) {
  return dayTimeNanoToNumber(e, R[n], 1);
}

function clampRelativeDuration(e, n, t, o, r, i) {
  const a = {
    ...ue,
    [ie[n]]: t
  }, s = i(o, e), c = i(s, a);
  return [ r(s), r(c) ];
}

function computeEpochNanoFrac(e, n, t) {
  const o = dayTimeNanoToNumber(diffDayTimeNanos(e, n));
  if (!o) {
    throw new RangeError(d);
  }
  return dayTimeNanoToNumber(diffDayTimeNanos(e, t)) / o;
}

function roundDateTime(e, n, t, o, r) {
  return 6 === n ? ((e, n, t) => {
    if (n) {
      const o = computeNanosecondsInDay(n, e);
      return checkIsoDateTimeInBounds({
        ...moveByIsoDays(e, roundByInc(isoTimeFieldsToNano(e), o, t) / o),
        ...Ae
      });
    }
    return roundDateTimeToNano(e, B, t);
  })(e, r, o) : roundDateTimeToNano(e, computeNanoInc(n, t), o);
}

function roundDateTimeToNano(e, n, t) {
  const [o, r] = roundTimeToNano(e, n, t);
  return checkIsoDateTimeInBounds({
    ...moveByIsoDays(e, r),
    ...o
  });
}

function roundTimeToNano(e, n, t) {
  return nanoToIsoTimeAndDay(roundByInc(isoTimeFieldsToNano(e), n, t));
}

function balanceDayTimeDuration(e, n, t, o, r) {
  return nanoToDurationDayTimeFields(roundDayTimeNano(durationFieldsToDayTimeNano(e, 6), t, o, r), n);
}

function balanceDayTimeDurationByInc(e, n, t, o) {
  return nanoToDurationDayTimeFields(roundDayTimeNanoByInc(durationFieldsToDayTimeNano(e, n), t, o), n);
}

function roundRelativeDuration(e, n, t, o, r, i, a, s, c) {
  const l = s === identityFunc ? o > 6 ? nudgeRelativeDuration : 6 === o ? nudgeDurationDayTime : nudgeRelativeDurationTime : o > 6 ? nudgeRelativeDuration : nudgeDurationDayTime;
  let [u, d, f] = l(e, n, t, o, r, i, a, s, c);
  return f && (u = ((e, n, t, o, r, i, a) => {
    const s = Hn(e);
    for (let c = o + 1; c <= t; c++) {
      if (7 === c && 7 !== t) {
        continue;
      }
      const o = clearDurationFields(e, c - 1);
      o[ie[c]] += s;
      const l = dayTimeNanoToNumber(diffDayTimeNanos(i(a(r, o)), n));
      if (l && Math.sign(l) !== s) {
        break;
      }
      e = o;
    }
    return e;
  })(u, d, t, Math.max(6, o), a, s, c)), u;
}

function computeNanoInc(e, n) {
  return R[e] * n;
}

function roundByInc(e, n, t) {
  return ((e, n) => Ve[n](e))(e / n, t) * n;
}

function roundToMinute(e) {
  return roundByInc(e, k, 7);
}

function roundDayTimeNano(e, n, t, o, r) {
  return 6 === n ? [ roundByInc(totalDayTimeNano(e, 6), t, o), 0 ] : roundDayTimeNanoByInc(e, computeNanoInc(n, t), o, r);
}

function roundDayTimeNanoByInc(e, n, t, o) {
  let [r, i] = e;
  o && i < 0 && (i += B, r -= 1);
  const [a, s] = divModFloor(roundByInc(i, n, t), B);
  return createDayTimeNano(r + a, s);
}

function nudgeDurationDayTime(e, n, t, o, r, i) {
  const a = Hn(e), s = durationFieldsToDayTimeNano(e, 6), c = roundDayTimeNano(s, o, r, i), l = diffDayTimeNanos(s, c), u = Math.sign(c[0] - s[0]) === a, d = nanoToDurationDayTimeFields(c, Math.min(t, 6));
  return [ {
    ...e,
    ...d
  }, addDayTimeNanos(n, l), u ];
}

function nudgeRelativeDurationTime(e, n, t, o, r, i, a, s, c) {
  const l = Hn(e);
  let [u, d] = givenFieldsToDayTimeNano(e, 5, ie);
  const f = computeNanoInc(o, r);
  let m = roundByInc(d, f, i);
  const [p, h] = clampRelativeDuration({
    ...e,
    ...de
  }, 6, l, a, s, c), T = m - dayTimeNanoToNumber(diffDayTimeNanos(p, h));
  T && Math.sign(T) !== l ? n = addDayTimeNanoAndNumber(p, m) : (u += l, m = roundByInc(T, f, i), 
  n = addDayTimeNanoAndNumber(h, m));
  const D = nanoToDurationTimeFields(m);
  return [ {
    ...e,
    ...D,
    days: e.days + u
  }, n, Boolean(u) ];
}

function nudgeRelativeDuration(e, n, t, o, r, i, a, s, c) {
  const l = Hn(e), u = ie[o], d = clearDurationFields(e, o - 1), f = divTrunc(e[u], r) * r;
  d[u] = f;
  const [m, p] = clampRelativeDuration(d, o, r * l, a, s, c), h = f + computeEpochNanoFrac(m, p, n) * l * r, T = roundByInc(h, r, i), D = Math.sign(T - h) === l;
  return d[u] = T, [ d, D ? p : m, D ];
}

function diffInstants(e, n, t, o) {
  const r = refineDiffOptions(o, copyOptions(t), 3, 5);
  let i = diffEpochNano(e.epochNanoseconds, n.epochNanoseconds, ...r);
  return createDurationSlots(o ? negateDurationFields(i) : i);
}

function diffZonedDateTimes(e, n, t, o, r, i) {
  const a = getCommonCalendarSlot(t.calendar, o.calendar), s = copyOptions(r), [c, l, u, d] = refineDiffOptions(i, s, 5), f = t.epochNanoseconds, p = o.epochNanoseconds, h = compareDayTimeNanos(p, f);
  let T;
  if (h) {
    if (c < 6) {
      T = diffEpochNano(f, p, c, l, u, d);
    } else {
      const r = n(((e, n) => {
        if (!isTimeZoneSlotsEqual(e, n, 1)) {
          throw new RangeError(m);
        }
        return e;
      })(t.timeZone, o.timeZone)), i = e(a);
      T = diffZonedEpochNanoViaCalendar(i, r, h, f, p, c, s), !h || 0 === l && 1 === u || (T = roundRelativeDuration(T, p, c, l, u, d, f, identityFunc, bindArgs(moveZonedEpochNano, i, r)));
    }
  } else {
    T = ue;
  }
  return createDurationSlots(i ? negateDurationFields(T) : T);
}

function diffPlainDateTimes(e, n, t, o, r) {
  const i = getCommonCalendarSlot(n.calendar, t.calendar), a = copyOptions(o), [s, c, l, u] = refineDiffOptions(r, a, 6), d = isoToEpochNano(n), f = isoToEpochNano(t), m = compareDayTimeNanos(f, d);
  let p;
  if (m) {
    if (s <= 6) {
      p = diffEpochNano(d, f, s, c, l, u);
    } else {
      const o = e(i);
      p = diffDateTimesViaCalendar(o, m, n, t, s, a), !m || 0 === c && 1 === l || (p = roundRelativeDuration(p, f, s, c, l, u, n, isoToEpochNano, bindArgs(moveDateTime, o)));
    }
  } else {
    p = ue;
  }
  return createDurationSlots(r ? negateDurationFields(p) : p);
}

function diffPlainDates(e, n, t, o, r) {
  const i = getCommonCalendarSlot(n.calendar, t.calendar), a = copyOptions(o);
  return diffDateLike(r || 0, (() => e(i)), n, t, ...refineDiffOptions(r, a, 6, 9, 6), a);
}

function diffPlainYearMonth(e, n, t, o, r) {
  const i = getCommonCalendarSlot(n.calendar, t.calendar), a = copyOptions(o), s = refineDiffOptions(r, a, 9, 9, 8), c = e(i);
  return diffDateLike(r || 0, (() => c), moveToMonthStart(c, n), moveToMonthStart(c, t), ...s, a);
}

function diffDateLike(e, n, t, o, r, i, a, s, c) {
  const l = isoToEpochNano(t), u = isoToEpochNano(o);
  let d;
  if (compareDayTimeNanos(u, l)) {
    let e;
    6 === r ? d = diffByDay(t, o) : (e = n(), d = e.dateUntil(t, o, r, c)), 6 === i && 1 === a || (e || (e = n()), 
    d = roundRelativeDuration(d, u, r, i, a, s, t, isoToEpochNano, ((n, t) => e.dateAdd(n, t))));
  } else {
    d = ue;
  }
  return createDurationSlots(e ? negateDurationFields(d) : d);
}

function diffPlainTimes(e, n, t, o) {
  const r = copyOptions(t), [i, a, s, c] = refineDiffOptions(o, r, 5, 5), l = isoTimeFieldsToNano(e), u = roundByInc(isoTimeFieldsToNano(n) - l, computeNanoInc(a, s), c);
  let d = {
    ...ue,
    ...nanoToDurationTimeFields(u, i)
  };
  return createDurationSlots(o ? negateDurationFields(d) : d);
}

function diffZonedEpochNanoExact(e, n, t, o, r, i) {
  const a = compareDayTimeNanos(o, t);
  return a ? r < 6 ? diffEpochNanoExact(t, o, r) : diffZonedEpochNanoViaCalendar(e, n, a, t, o, r, i) : ue;
}

function diffDateTimesExact(e, n, t, o, r) {
  const i = isoToEpochNano(n), a = isoToEpochNano(t), s = compareDayTimeNanos(a, i);
  return s ? o <= 6 ? diffEpochNanoExact(i, a, o) : diffDateTimesViaCalendar(e, s, n, t, o, r) : ue;
}

function diffZonedEpochNanoViaCalendar(e, n, t, o, r, i, a) {
  const s = zonedEpochNanoToIso(n, o), c = pluckProps(Be, s), l = zonedEpochNanoToIso(n, r), u = bindArgs(getSingleInstantFor, n);
  let f, m, p, h = 0;
  do {
    if (h > 2) {
      throw new RangeError(d);
    }
    f = {
      ...moveByIsoDays(l, h++ * -t),
      ...c
    }, m = u(f), p = compareDayTimeNanos(r, m);
  } while (p === -t);
  return {
    ...6 === i ? diffByDay(s, f) : e.dateUntil(s, f, i, a),
    ...nanoToDurationTimeFields(dayTimeNanoToNumber(diffDayTimeNanos(m, r)))
  };
}

function diffDateTimesViaCalendar(e, n, t, o, r, i) {
  const a = isoTimeFieldsToNano(t);
  let s = isoTimeFieldsToNano(o) - a, c = t;
  return Math.sign(s) === -n && (c = moveByIsoDays(t, n), s += B * n), {
    ...e.dateUntil({
      ...c,
      ...Ae
    }, {
      ...o,
      ...Ae
    }, r, i),
    ...nanoToDurationTimeFields(s)
  };
}

function diffEpochNano(e, n, t, o, r, i) {
  return {
    ...ue,
    ...nanoToDurationDayTimeFields(roundDayTimeNano(diffDayTimeNanos(e, n), o, r, i), t)
  };
}

function diffEpochNanoExact(e, n, t) {
  return {
    ...ue,
    ...nanoToDurationDayTimeFields(diffDayTimeNanos(e, n), t)
  };
}

function diffByDay(e, n) {
  return {
    ...ue,
    days: diffDays(e, n)
  };
}

function diffDays(e, n) {
  return diffEpochMilliByDay(isoToEpochMilli(e), isoToEpochMilli(n));
}

function diffEpochMilliByDay(e, n) {
  return Math.round((n - e) / b);
}

function computeIsoMonthsInYear() {
  return xn;
}

function computeIsoDaysInMonth(e, n) {
  switch (n) {
   case 2:
    return computeIsoInLeapYear(e) ? 29 : 28;

   case 4:
   case 6:
   case 9:
   case 11:
    return 30;
  }
  return 31;
}

function computeIsoDaysInYear(e) {
  return computeIsoInLeapYear(e) ? 366 : 365;
}

function computeIsoInLeapYear(e) {
  return e % 4 == 0 && (e % 100 != 0 || e % 400 == 0);
}

function computeIsoDayOfYear(e) {
  return diffEpochMilliByDay(isoToEpochMilli(isoDateYearStart(e)), isoToEpochMilli({
    ...e,
    ...Ae
  })) + 1;
}

function computeIsoDayOfWeek(e) {
  const [n, t] = isoToLegacyDate(e.isoYear, e.isoMonth, e.isoDay);
  return modFloor(n.getDay() + 1 - t, 7) || 7;
}

function computeIsoWeekParts(e) {
  const n = computeIsoDayOfYear(e), t = computeIsoDayOfWeek(e), o = computeIsoDayOfWeek(isoDateYearStart(e)), r = Math.floor((n - t + 10) / $n), {isoYear: i} = e;
  return r < 1 ? [ i - 1, 5 === o || 6 === o && computeIsoInLeapYear(i - 1) ? 53 : 52 ] : 53 === r && computeIsoDaysInYear(i) - n < 4 - t ? [ i + 1, 1 ] : [ i, r ];
}

function isoDateYearStart(e) {
  return {
    ...e,
    isoMonth: 1,
    isoDay: 1,
    ...Ae
  };
}

function computeGregoryEraParts({isoYear: e}) {
  return e < 1 ? [ "bce", 1 - e ] : [ "ce", e ];
}

function checkIsoDateTimeFields(e) {
  return checkIsoDateFields(e), constrainIsoTimeFields(e, 1), e;
}

function checkIsoDateFields(e) {
  return constrainIsoDateFields(e, 1), e;
}

function isIsoDateFieldsValid(e) {
  return allFieldsEqual(Re, e, constrainIsoDateFields(e));
}

function constrainIsoDateFields(e, n) {
  const {isoYear: t} = e, o = clampProp(e, "isoMonth", 1, computeIsoMonthsInYear(), n);
  return {
    isoYear: t,
    isoMonth: o,
    isoDay: clampProp(e, "isoDay", 1, computeIsoDaysInMonth(t, o), n)
  };
}

function constrainIsoTimeFields(e, n) {
  return zipProps(Be, [ clampProp(e, "isoHour", 0, 23, n), clampProp(e, "isoMinute", 0, 59, n), clampProp(e, "isoSecond", 0, 59, n), clampProp(e, "isoMillisecond", 0, 999, n), clampProp(e, "isoMicrosecond", 0, 999, n), clampProp(e, "isoNanosecond", 0, 999, n) ]);
}

function moveInstant(e, n, t) {
  return createInstantSlots(checkEpochNanoInBounds(addDayTimeNanos(e.epochNanoseconds, (e => {
    if (durationHasDateParts(e)) {
      throw new RangeError(y);
    }
    return durationFieldsToDayTimeNano(e, 5);
  })(t ? negateDurationFields(n) : n))));
}

function moveZonedDateTime(e, n, t, o, r = Object.create(null), i) {
  const a = n(t.timeZone), s = moveZonedEpochNano(e(t.calendar), a, t.epochNanoseconds, i ? negateDurationFields(o) : o, r);
  return {
    ...t,
    epochNanoseconds: s
  };
}

function movePlainDateTime(e, n, t, o = Object.create(null), r) {
  return createPlainDateTimeSlots({
    ...n,
    ...moveDateTime(e(n.calendar), n, r ? negateDurationFields(t) : t, o)
  });
}

function movePlainDate(e, n, t, o, r) {
  return {
    ...n,
    ...moveDateEfficient(e(n.calendar), n, r ? negateDurationFields(t) : t, o)
  };
}

function movePlainYearMonth(e, n, t, o = Object.create(null), r) {
  const i = n.calendar, a = e(i);
  let s = moveToMonthStart(a, n);
  r && (t = negateDuration(t)), Hn(t) < 0 && (s = a.dateAdd(s, {
    ...ue,
    months: 1
  }), s = moveByIsoDays(s, -1));
  const c = a.dateAdd(s, t, o);
  return createPlainYearMonthSlots(moveToMonthStart(a, c), i);
}

function movePlainTime(e, n, t) {
  return createPlainTimeSlots(moveTime(e, t ? negateDurationFields(n) : n)[0]);
}

function moveZonedEpochNano(e, n, t, o, r) {
  const i = durationFieldsToDayTimeNano(o, 5);
  if (durationHasDateParts(o)) {
    const a = zonedEpochNanoToIso(n, t);
    t = addDayTimeNanos(getSingleInstantFor(n, {
      ...moveDateEfficient(e, a, {
        ...o,
        ...de
      }, r),
      ...pluckProps(Be, a),
      calendar: we
    }), i);
  } else {
    t = addDayTimeNanos(t, i), refineOverflowOptions(r);
  }
  return checkEpochNanoInBounds(t);
}

function moveDateTime(e, n, t, o) {
  const [r, i] = moveTime(n, t);
  return checkIsoDateTimeInBounds({
    ...moveDateEfficient(e, n, {
      ...t,
      ...de,
      days: t.days + i
    }, o),
    ...r
  });
}

function moveDateEfficient(e, n, t, o) {
  if (t.years || t.months || t.weeks) {
    return e.dateAdd(n, t, o);
  }
  refineOverflowOptions(o);
  const r = t.days + givenFieldsToDayTimeNano(t, 5, ie)[0];
  return r ? checkIsoDateInBounds(moveByIsoDays(n, r)) : n;
}

function moveToMonthStart(e, n) {
  return moveByIsoDays(n, 1 - e.day(n));
}

function moveTime(e, n) {
  const [t, o] = givenFieldsToDayTimeNano(n, 5, ie), [r, i] = nanoToIsoTimeAndDay(isoTimeFieldsToNano(e) + o);
  return [ r, t + i ];
}

function moveByIsoDays(e, n) {
  return n && (e = epochMilliToIso(isoToEpochMilli(e) + n * b)), e;
}

function createMarkerSystem(e, n, t) {
  const {calendar: o, timeZone: r, epochNanoseconds: i} = t, a = e(o);
  if (i) {
    const e = n(r);
    return [ i, identityFunc, bindArgs(moveZonedEpochNano, a, e), bindArgs(diffZonedEpochNanoExact, a, e) ];
  }
  return [ {
    ...t,
    ...Ae
  }, isoToEpochNano, bindArgs(moveDateTime, a), bindArgs(diffDateTimesExact, a) ];
}

function spanDuration(e, n, t, o, r, i, a) {
  let s = i(o, e);
  return n && (s = i(s, n)), [ a(o, s, t), r(s) ];
}

function addDurations(e, n, t, o, r, i, a) {
  const s = e(normalizeOptions(i).relativeTo), c = Math.max(getLargestDurationUnit(o), getLargestDurationUnit(r));
  if (c < 6 || 6 === c && (!s || !s.epochNanoseconds)) {
    return createDurationSlots(((e, n, t, o) => {
      const r = addDayTimeNanos(durationFieldsToDayTimeNano(e, 6), durationFieldsToDayTimeNano(n, 6), o ? -1 : 1);
      if (!Number.isFinite(r[0])) {
        throw new RangeError(D);
      }
      return {
        ...ue,
        ...nanoToDurationDayTimeFields(r, t)
      };
    })(o, r, c, a));
  }
  if (!s) {
    throw new RangeError(I);
  }
  return a && (r = negateDurationFields(r)), createDurationSlots(spanDuration(o, r, c, ...createMarkerSystem(n, t, s))[0]);
}

function negateDuration(e) {
  return createDurationSlots(negateDurationFields(e));
}

function negateDurationFields(e) {
  const n = {};
  for (const t of ie) {
    n[t] = -1 * e[t] || 0;
  }
  return n;
}

function computeDurationSign(e, n = ie) {
  let t = 0;
  for (const o of n) {
    const n = Math.sign(e[o]);
    if (n) {
      if (t && t !== n) {
        throw new RangeError(g);
      }
      t = n;
    }
  }
  return t;
}

function checkDurationFields(e) {
  return Hn(e), e;
}

function durationFieldsToDayTimeNano(e, n) {
  return givenFieldsToDayTimeNano(e, n, ie);
}

function nanoToDurationDayTimeFields(e, n = 6) {
  const [t, o] = e, r = nanoToGivenFields(o, n, ie);
  if (r[ie[n]] += t * (B / R[n]), !Number.isFinite(r[ie[n]])) {
    throw new RangeError(D);
  }
  return r;
}

function nanoToDurationTimeFields(e, n = 5) {
  return nanoToGivenFields(e, n, ie);
}

function clearDurationFields(e, n) {
  const t = {
    ...e
  };
  for (let e = 0; e <= n; e++) {
    t[ie[e]] = 0;
  }
  return t;
}

function durationHasDateParts(e) {
  return Boolean(computeDurationSign(e, ce));
}

function getLargestDurationUnit(e) {
  let n = 9;
  for (;n > 0 && !e[ie[n]]; n--) {}
  return n;
}

function realizeCalendarId(e) {
  return (e = normalizeCalendarId(e)) !== we && e !== Ee && kn(e), e;
}

function normalizeCalendarId(e) {
  return "islamicc" === (e = e.toLocaleLowerCase()) && (e = "islamic-civil"), e;
}

function parseOffsetNano(e) {
  const n = parseOffsetNanoMaybe(e);
  if (void 0 === n) {
    throw new RangeError(failedParse(e));
  }
  return n;
}

function parsePlainDate(e) {
  const n = parseDateTimeLike(ne(e));
  if (!n || n.I) {
    throw new RangeError(failedParse(e));
  }
  return createPlainDateSlots(n.N ? finalizeDateTime(n) : finalizeDate(n));
}

function requireIsoCalendar(e) {
  if (e.calendar !== we) {
    throw new RangeError(invalidSubstring(e.calendar));
  }
}

function finalizeZonedDateTime(e, n, t = 0, o = 0) {
  const r = queryNativeTimeZone(e.timeZone);
  return createZonedDateTimeSlots(getMatchingInstantFor(r, checkIsoDateTimeFields(e), n, t, o, !(r instanceof FixedTimeZone), e.I), r.id, realizeCalendarId(e.calendar));
}

function finalizeDateTime(e) {
  return realizeCalendarSlot(checkIsoDateTimeInBounds(checkIsoDateTimeFields(e)));
}

function finalizeDate(e) {
  return realizeCalendarSlot(checkIsoDateInBounds(checkIsoDateFields(e)));
}

function realizeCalendarSlot(e) {
  return {
    ...e,
    calendar: realizeCalendarId(e.calendar)
  };
}

function parseDateTimeLike(e) {
  const n = ut.exec(e);
  return n ? (e => {
    const n = e[10], t = "Z" === (n || "").toUpperCase();
    return {
      isoYear: organizeIsoYearParts(e),
      isoMonth: parseInt(e[4]),
      isoDay: parseInt(e[5]),
      ...organizeTimeParts(e.slice(5)),
      ...organizeAnnotationParts(e[16]),
      N: Boolean(e[6]),
      I: t,
      offset: t ? void 0 : n
    };
  })(n) : void 0;
}

function parseYearMonthOnly(e) {
  const n = ct.exec(e);
  return n ? (e => ({
    isoYear: organizeIsoYearParts(e),
    isoMonth: parseInt(e[4]),
    isoDay: 1,
    ...organizeAnnotationParts(e[5])
  }))(n) : void 0;
}

function parseMonthDayOnly(e) {
  const n = lt.exec(e);
  return n ? (e => ({
    isoYear: Un,
    isoMonth: parseInt(e[1]),
    isoDay: parseInt(e[2]),
    ...organizeAnnotationParts(e[3])
  }))(n) : void 0;
}

function parseOffsetNanoMaybe(e, n) {
  const t = ft.exec(e);
  return t ? ((e, n) => {
    const t = e[4] || e[5];
    if (n && t) {
      throw new RangeError(invalidSubstring(t));
    }
    return validateTimeZoneOffset((parseInt0(e[2]) * Y + parseInt0(e[3]) * k + parseInt0(e[4]) * Z + parseSubsecNano(e[5] || "")) * parseSign(e[1]));
  })(t, n) : void 0;
}

function organizeIsoYearParts(e) {
  const n = parseSign(e[1]), t = parseInt(e[2] || e[3]);
  if (n < 0 && !t) {
    throw new RangeError(invalidSubstring(-0));
  }
  return n * t;
}

function organizeTimeParts(e) {
  const n = parseInt0(e[3]);
  return {
    ...nanoToIsoTimeAndDay(parseSubsecNano(e[4] || ""))[0],
    isoHour: parseInt0(e[1]),
    isoMinute: parseInt0(e[2]),
    isoSecond: 60 === n ? 59 : n
  };
}

function organizeAnnotationParts(e) {
  let n, t;
  const o = [];
  if (e.replace(mt, ((e, r, i) => {
    const a = Boolean(r), [s, c] = i.split("=").reverse();
    if (c) {
      if ("u-ca" === c) {
        o.push(s), n || (n = a);
      } else if (a) {
        throw new RangeError(invalidSubstring(e));
      }
    } else {
      if (t) {
        throw new RangeError(invalidSubstring(e));
      }
      t = s;
    }
    return "";
  })), o.length > 1 && n) {
    throw new RangeError(invalidSubstring(e));
  }
  return {
    timeZone: t,
    calendar: o[0] || we
  };
}

function parseSubsecNano(e) {
  return parseInt(e.padEnd(9, "0"));
}

function createRegExp(e) {
  return new RegExp(`^${e}$`, "i");
}

function parseSign(e) {
  return e && "+" !== e ? -1 : 1;
}

function parseInt0(e) {
  return void 0 === e ? 0 : parseInt(e);
}

function createInstantSlots(e) {
  return {
    O: St,
    epochNanoseconds: e
  };
}

function createZonedDateTimeSlots(e, n, t) {
  return {
    O: yt,
    calendar: t,
    timeZone: n,
    epochNanoseconds: e
  };
}

function createPlainDateTimeSlots(e, n = e.calendar) {
  return {
    O: gt,
    calendar: n,
    ...pluckProps(ze, e)
  };
}

function createPlainDateSlots(e, n = e.calendar) {
  return {
    O: Dt,
    calendar: n,
    ...pluckProps(je, e)
  };
}

function createPlainYearMonthSlots(e, n = e.calendar) {
  return {
    O: ht,
    calendar: n,
    ...pluckProps(je, e)
  };
}

function createPlainMonthDaySlots(e, n = e.calendar) {
  return {
    O: Tt,
    calendar: n,
    ...pluckProps(je, e)
  };
}

function createPlainTimeSlots(e) {
  return {
    O: It,
    ...pluckProps(qe, e)
  };
}

function createDurationSlots(e) {
  return {
    O: Nt,
    ...pluckProps(ae, e)
  };
}

function removeBranding(e) {
  return delete (e = {
    ...e
  }).O, e;
}

function getCommonCalendarSlot(e, n) {
  if (!isIdLikeEqual(e, n)) {
    throw new RangeError(f);
  }
  return e;
}

function getPreferredCalendarSlot(e, n) {
  if (e === n) {
    return e;
  }
  const t = getId(e), o = getId(n);
  if (t === o || t === we) {
    return n;
  }
  if (o === we) {
    return e;
  }
  throw new RangeError(f);
}

function isTimeZoneSlotsEqual(e, n, t) {
  return e === n || getTimeZoneSlotRaw(e, t) === getTimeZoneSlotRaw(n, t);
}

function getTimeZoneSlotRaw(e, n) {
  const t = getId(e);
  if (n && t === Yn) {
    return 0;
  }
  const o = parseOffsetNanoMaybe(t);
  return void 0 !== o ? o : t;
}

function getId(e) {
  return "string" == typeof e ? e : ne(e.id);
}

function isIdLikeEqual(e, n) {
  return e === n || getId(e) === getId(n);
}

function createCalendarFieldMethods(e, n) {
  const t = {};
  for (const o in e) {
    t[o] = ({P: e}, t) => {
      const r = Uo(t) || {}, {O: i} = r, a = i === Dt || n.includes(i) ? r : toPlainDateSlots(t);
      return e[o](a);
    };
  }
  return t;
}

function createCalendarGetters(e) {
  const n = {};
  for (const t in e) {
    n[t] = e => {
      const {calendar: n} = e;
      return (o = n, "string" == typeof o ? Kn(o) : (r = o, Object.assign(Object.create(kt), {
        v: r
      })))[t](e);
      var o, r;
    };
  }
  return n;
}

function neverValueOf() {
  throw new TypeError("Cannot use valueOf");
}

function getCalendarFromSlots({calendar: e}) {
  return "string" == typeof e ? new Go(e) : e;
}

function compareInstants(e, n) {
  return compareDayTimeNanos(e.epochNanoseconds, n.epochNanoseconds);
}

function compareZonedDateTimes(e, n) {
  return compareDayTimeNanos(e.epochNanoseconds, n.epochNanoseconds);
}

function compareIsoDateTimeFields(e, n) {
  return compareIsoDateFields(e, n) || compareIsoTimeFields(e, n);
}

function compareIsoDateFields(e, n) {
  return compareNumbers(isoToEpochMilli(e), isoToEpochMilli(n));
}

function compareIsoTimeFields(e, n) {
  return compareNumbers(isoTimeFieldsToNano(e), isoTimeFieldsToNano(n));
}

function instantToZonedDateTime(e, n, t = we) {
  return createZonedDateTimeSlots(e.epochNanoseconds, n, t);
}

function zonedDateTimeToPlainDateTime(e, n) {
  return createPlainDateTimeSlots(zn(n, e(n.timeZone)), n.calendar);
}

function zonedDateTimeToPlainDate(e, n) {
  return createPlainDateSlots(zn(n, e(n.timeZone)), n.calendar);
}

function zonedDateTimeToPlainTime(e, n) {
  return createPlainTimeSlots(zn(n, e(n.timeZone)));
}

function toPlainMonthDaySlots(e, n) {
  if (n = copyOptions(n), isObjectLike(e)) {
    const t = Uo(e);
    if (t && t.O === Tt) {
      return refineOverflowOptions(n), t;
    }
    const o = extractCalendarSlotFromBag(e);
    return refinePlainMonthDayBag(mo(o || we), !o, e, n);
  }
  const t = ((e, n) => {
    const t = parseMonthDayOnly(ne(n));
    if (t) {
      return requireIsoCalendar(t), createPlainMonthDaySlots(checkIsoDateFields(t));
    }
    const o = parsePlainDate(n), {calendar: r} = o, i = e(r), [a, s, c] = i.F(o), [l, u] = i.C(a, s), [d, f] = i.k(l, u, c);
    return createPlainMonthDaySlots(i.B(d, f, c), r);
  })(Kn, e);
  return refineOverflowOptions(n), t;
}

function toPlainYearMonthSlots(e, n) {
  if (n = copyOptions(n), isObjectLike(e)) {
    const t = Uo(e);
    return t && t.O === ht ? (refineOverflowOptions(n), t) : refinePlainYearMonthBag(uo(getCalendarSlotFromBag(e)), e, n);
  }
  const t = ((e, n) => {
    const t = parseYearMonthOnly(ne(n));
    if (t) {
      return requireIsoCalendar(t), createPlainYearMonthSlots(checkIsoYearMonthInBounds(checkIsoDateFields(t)));
    }
    const o = parsePlainDate(n), r = moveToMonthStart(e(o.calendar), o);
    return createPlainYearMonthSlots({
      ...o,
      ...r
    });
  })(Kn, e);
  return refineOverflowOptions(n), t;
}

function dayAdapter(e, n, t) {
  return requirePositiveInteger(n.call(e, Ro(createPlainDateSlots(t, e))));
}

function createCompoundOpsCreator(e) {
  return n => "string" == typeof n ? Kn(n) : ((e, n) => {
    const t = Object.keys(n).sort(), o = {};
    for (const r of t) {
      o[r] = bindArgs(n[r], e, e[r]);
    }
    return o;
  })(n, e);
}

function getImplTransition(e, n, t) {
  const o = n.R(toInstantSlots(t).epochNanoseconds, e);
  return o ? Mo(createInstantSlots(o)) : null;
}

function slotsWithCalendar(e, n) {
  return {
    ...e,
    calendar: n
  };
}

function adaptToIsoFields(e) {
  return mapProps((e => n => e(slotsToIsoFields(n))), e);
}

function slotsToIsoFields(e) {
  const n = createSimpleTimeZoneOps(e.timeZone);
  return {
    ...zn(e, n),
    calendar: e.calendar
  };
}

function toZonedDateTimeSlots(e, n) {
  if (n = copyOptions(n), isObjectLike(e)) {
    const t = Uo(e);
    if (t && t.O === yt) {
      return refineZonedFieldOptions(n), t;
    }
    const o = getCalendarSlotFromBag(e);
    return ((e, n, t, o, r, i) => {
      const a = refineCalendarFields(t, r, K, z, U), s = e(a.timeZone), [c, l, u] = refineZonedFieldOptions(i), d = t.dateFromFields(a, overrideOverflowOptions(i, c)), f = refineTimeBag(a, c);
      return createZonedDateTimeSlots(getMatchingInstantFor(n(s), {
        ...d,
        ...f
      }, void 0 !== a.offset ? parseOffsetNano(a.offset) : void 0, l, u), s, o);
    })(refineTimeZoneSlot, createTimeZoneOps, fo(o), o, e, n);
  }
  return ((e, n) => {
    const t = parseDateTimeLike(ne(e));
    if (!t || !t.timeZone) {
      throw new RangeError(failedParse(e));
    }
    const {offset: o} = t, r = o ? parseOffsetNano(o) : void 0, [, i, a] = refineZonedFieldOptions(n);
    return finalizeZonedDateTime(t, r, i, a);
  })(e, n);
}

function toInstantSlots(e) {
  if (isObjectLike(e)) {
    const n = Uo(e);
    if (n) {
      switch (n.O) {
       case St:
        return n;

       case yt:
        return createInstantSlots(n.epochNanoseconds);
      }
    }
  }
  return (e => {
    const n = parseDateTimeLike(e = toStringViaPrimitive(e));
    if (!n) {
      throw new RangeError(failedParse(e));
    }
    let t;
    if (n.I) {
      t = 0;
    } else {
      if (!n.offset) {
        throw new RangeError(failedParse(e));
      }
      t = parseOffsetNano(n.offset);
    }
    return n.timeZone && parseOffsetNanoMaybe(n.timeZone, 1), createInstantSlots(isoToEpochNanoWithOffset(checkIsoDateTimeFields(n), t));
  })(e);
}

function toTemporalInstant() {
  return Mo(createInstantSlots(numberToDayTimeNano(this.valueOf(), C)));
}

function adapterGetOffsetNanosecondsFor(e, n, t) {
  return validateTimeZoneOffset(requireInteger(n.call(e, Mo(createInstantSlots(t)))));
}

function createAdapterOps(e, n = bo) {
  const t = Object.keys(n).sort(), o = {};
  for (const r of t) {
    o[r] = bindArgs(n[r], e, re(e[r]));
  }
  return o;
}

function createTimeZoneOps(e, n) {
  return "string" == typeof e ? queryNativeTimeZone(e) : createAdapterOps(e, n);
}

function createSimpleTimeZoneOps(e) {
  return createTimeZoneOps(e, wo);
}

function toDurationSlots(e) {
  if (isObjectLike(e)) {
    const n = Uo(e);
    return n && n.O === Nt ? n : (e => {
      const n = refineFields(e, ae);
      return createDurationSlots(checkDurationFields({
        ...ue,
        ...n
      }));
    })(e);
  }
  return (e => {
    const n = (e => {
      const n = pt.exec(e);
      return n ? (e => {
        function parseUnit(e, t, i) {
          let a = 0, s = 0;
          if (i && ([a, r] = divModFloor(r, R[i])), void 0 !== e) {
            if (o) {
              throw new RangeError(invalidSubstring(e));
            }
            s = (e => {
              const n = parseInt(e);
              if (!Number.isFinite(n)) {
                throw new RangeError(invalidSubstring(e));
              }
              return n;
            })(e), n = 1, t && (r = parseSubsecNano(t) * (R[i] / Z), o = 1);
          }
          return a + s;
        }
        let n = 0, o = 0, r = 0, i = {
          ...zipProps(ie, [ parseUnit(e[2]), parseUnit(e[3]), parseUnit(e[4]), parseUnit(e[5]), parseUnit(e[6], e[7], 5), parseUnit(e[8], e[9], 4), parseUnit(e[10], e[11], 3) ]),
          ...nanoToGivenFields(r, 2, ie)
        };
        if (!n) {
          throw new RangeError(t);
        }
        return parseSign(e[1]) < 0 && (i = negateDurationFields(i)), i;
      })(n) : void 0;
    })(ne(e));
    if (!n) {
      throw new RangeError(failedParse(e));
    }
    return createDurationSlots(n);
  })(e);
}

function refinePublicRelativeTo(e) {
  if (void 0 !== e) {
    if (isObjectLike(e)) {
      const n = Uo(e) || {};
      switch (n.O) {
       case yt:
       case Dt:
        return n;

       case gt:
        return createPlainDateSlots(n);
      }
      const t = getCalendarSlotFromBag(e);
      return {
        ...((e, n, t, o) => {
          const r = refineCalendarFields(t, o, K, [], U);
          if (void 0 !== r.timeZone) {
            const o = t.dateFromFields(r), i = refineTimeBag(r), a = e(r.timeZone);
            return {
              epochNanoseconds: getMatchingInstantFor(n(a), {
                ...o,
                ...i
              }, void 0 !== r.offset ? parseOffsetNano(r.offset) : void 0),
              timeZone: a
            };
          }
          return {
            ...t.dateFromFields(r),
            ...Ae
          };
        })(refineTimeZoneSlot, createTimeZoneOps, fo(t), e),
        calendar: t
      };
    }
    return (e => {
      const n = parseDateTimeLike(ne(e));
      if (!n) {
        throw new RangeError(failedParse(e));
      }
      if (n.timeZone) {
        return finalizeZonedDateTime(n, n.offset ? parseOffsetNano(n.offset) : void 0);
      }
      if (n.I) {
        throw new RangeError(failedParse(e));
      }
      return finalizeDate(n);
    })(e);
  }
}

function toPlainDateTimeSlots(e, n) {
  if (n = copyOptions(n), isObjectLike(e)) {
    const t = Uo(e) || {};
    switch (t.O) {
     case gt:
      return refineOverflowOptions(n), t;

     case Dt:
      return refineOverflowOptions(n), createPlainDateTimeSlots({
        ...t,
        ...Ae
      });

     case yt:
      return refineOverflowOptions(n), zonedDateTimeToPlainDateTime(createSimpleTimeZoneOps, t);
    }
    return ((e, n, t) => {
      const o = refineCalendarFields(e, n, K, [], L), r = refineOverflowOptions(t);
      return createPlainDateTimeSlots(checkIsoDateTimeInBounds({
        ...e.dateFromFields(o, overrideOverflowOptions(t, r)),
        ...refineTimeBag(o, r)
      }));
    })(fo(getCalendarSlotFromBag(e)), e, n);
  }
  const t = (e => {
    const n = parseDateTimeLike(ne(e));
    if (!n || n.I) {
      throw new RangeError(failedParse(e));
    }
    return createPlainDateTimeSlots(finalizeDateTime(n));
  })(e);
  return refineOverflowOptions(n), t;
}

function toPlainDateSlots(e, n) {
  if (n = copyOptions(n), isObjectLike(e)) {
    const t = Uo(e) || {};
    switch (t.O) {
     case Dt:
      return refineOverflowOptions(n), t;

     case gt:
      return refineOverflowOptions(n), createPlainDateSlots(t);

     case yt:
      return refineOverflowOptions(n), zonedDateTimeToPlainDate(createSimpleTimeZoneOps, t);
    }
    return refinePlainDateBag(fo(getCalendarSlotFromBag(e)), e, n);
  }
  const t = parsePlainDate(e);
  return refineOverflowOptions(n), t;
}

function toPlainTimeSlots(e, n) {
  if (isObjectLike(e)) {
    const t = Uo(e) || {};
    switch (t.O) {
     case It:
      return refineOverflowOptions(n), t;

     case gt:
      return refineOverflowOptions(n), createPlainTimeSlots(t);

     case yt:
      return refineOverflowOptions(n), zonedDateTimeToPlainTime(createSimpleTimeZoneOps, t);
    }
    return ((e, n) => {
      const t = refineOverflowOptions(n);
      return createPlainTimeSlots(refineTimeBag(refineFields(e, j, [], 1), t));
    })(e, n);
  }
  return refineOverflowOptions(n), (e => {
    let n, t = (e => {
      const n = dt.exec(e);
      return n ? (organizeAnnotationParts(n[10]), organizeTimeParts(n)) : void 0;
    })(ne(e));
    if (!t) {
      if (t = parseDateTimeLike(e), !t) {
        throw new RangeError(failedParse(e));
      }
      if (!t.N) {
        throw new RangeError(failedParse(e));
      }
      if (t.I) {
        throw new RangeError(invalidSubstring("Z"));
      }
      requireIsoCalendar(t);
    }
    if ((n = parseYearMonthOnly(e)) && isIsoDateFieldsValid(n)) {
      throw new RangeError(failedParse(e));
    }
    if ((n = parseMonthDayOnly(e)) && isIsoDateFieldsValid(n)) {
      throw new RangeError(failedParse(e));
    }
    return createPlainTimeSlots(constrainIsoTimeFields(t, 1));
  })(e);
}

function createProtocolChecker(e) {
  return e = e.concat("id").sort(), n => {
    if (!((e, n) => {
      for (const t of n) {
        if (!(t in e)) {
          return 0;
        }
      }
      return 1;
    })(n, e)) {
      throw new TypeError("Invalid protocol");
    }
  };
}

function optionalToPlainTimeFields(e) {
  return void 0 === e ? void 0 : toPlainTimeSlots(e);
}

function createSlotClass(e, n, t, r, i) {
  function Class(...e) {
    if (!(this instanceof Class)) {
      throw new TypeError(o);
    }
    xo(this, n(...e));
  }
  function curryMethod(n, t) {
    return Object.defineProperties((function(...t) {
      const r = Uo(this);
      if (!r || r.O !== e) {
        throw new TypeError(o);
      }
      return n.call(this, r, ...t);
    }), createNameDescriptors(t));
  }
  return Object.defineProperties(Class.prototype, {
    ...createGetterDescriptors(mapProps(curryMethod, t)),
    ...createPropDescriptors(mapProps(curryMethod, r)),
    ...createStringTagDescriptors("Temporal." + e)
  }), Object.defineProperties(Class, {
    ...createPropDescriptors(i),
    ...createNameDescriptors(e)
  }), [ Class, e => {
    const n = Object.create(Class.prototype);
    return xo(n, e), n;
  }, n => {
    const t = Uo(n);
    if (!t || t.O !== e) {
      throw new TypeError(o);
    }
    return t;
  } ];
}

function rejectInvalidBag(e) {
  if (Uo(e) || void 0 !== e.calendar || void 0 !== e.timeZone) {
    throw new TypeError("Invalid bag");
  }
  return e;
}

function refineCalendarSlot(e) {
  if (isObjectLike(e)) {
    const {calendar: n} = Uo(e) || {};
    return n || (Wo(e), e);
  }
  return (e => realizeCalendarId((e => {
    const n = parseDateTimeLike(e) || parseYearMonthOnly(e) || parseMonthDayOnly(e);
    return n ? n.calendar : e;
  })(ne(e))))(e);
}

function getCalendarSlotFromBag(e) {
  return extractCalendarSlotFromBag(e) || we;
}

function extractCalendarSlotFromBag(e) {
  const {calendar: n} = e;
  if (void 0 !== n) {
    return refineCalendarSlot(n);
  }
}

function refineTimeZoneSlot(e) {
  if (isObjectLike(e)) {
    const {timeZone: n} = Uo(e) || {};
    return n || (zo(e), e);
  }
  return (e => queryNativeTimeZone((e => {
    const n = parseDateTimeLike(e);
    return n && (n.timeZone || n.I && Yn || n.offset) || e;
  })(ne(e))).id)(e);
}

function getCurrentIsoDateTime(e) {
  const n = {
    epochNanoseconds: getCurrentEpochNanoseconds()
  };
  return pluckProps(Le, zn(n, e));
}

function getCurrentEpochNanoseconds() {
  return numberToDayTimeNano(Date.now(), C);
}

function getCurrentTimeZoneId() {
  return Vo || (Vo = (new He).resolvedOptions().timeZone);
}

const expectedInteger = (e, n) => `Non-integer ${e}: ${n}`, expectedPositive = (e, n) => `Non-positive ${e}: ${n}`, expectedFinite = (e, n) => `Non-finite ${e}: ${n}`, forbiddenBigIntToNumber = e => `Cannot convert bigint to ${e}`, invalidBigInt = e => `Invalid bigint: ${e}`, e = "Cannot convert Symbol to string", n = "Invalid object", numberOutOfRange = (e, n, t, o) => `${e} ${n} must be between ${t}-${o}`, invalidEntity = (e, n) => `Invalid ${e}: ${n}`, missingField = e => `Missing ${e}`, forbiddenField = e => `Invalid field ${e}`, duplicateFields = e => `Duplicate field ${e}`, t = "No valid fields", o = "Invalid calling context", r = "Forbidden era/eraYear", i = "Mismatching era/eraYear", a = "Mismatching year/eraYear", invalidEra = e => `Invalid era: ${e}`, missingYear = e => "Missing year" + (e ? "/era/eraYear" : ""), invalidMonthCode = e => `Invalid monthCode: ${e}`, s = "Mismatching month/monthCode", c = "Missing month/monthCode", l = "Cannot guess year", u = "Invalid leap month", d = "Invalid protocol results", f = "Mismatching Calendars", m = "Mismatching TimeZones", p = "Out-of-bounds offset", h = "Invalid offset for TimeZone", T = "Ambiguous offset", D = "Out-of-bounds date", g = "Cannot mix duration signs", I = "Missing relativeTo", y = "Cannot use large units", S = "smallestUnit > largestUnit", failedParse = e => `Cannot parse: ${e}`, invalidSubstring = e => `Invalid substring: ${e}`, N = /object|function/, O = bindArgs(mapPropNames, ((e, n) => n)), P = bindArgs(mapPropNames, ((e, n, t) => t)), v = bindArgs(padNumber, 2), M = {
  nanosecond: 0,
  microsecond: 1,
  millisecond: 2,
  second: 3,
  minute: 4,
  hour: 5,
  day: 6,
  week: 7,
  month: 8,
  year: 9
}, F = Object.keys(M), b = 864e5, w = 1e3, E = 1e3, C = 1e6, Z = 1e9, k = 6e10, Y = 36e11, B = 864e11, R = [ 1, E, C, Z, k, Y, B ], L = F.slice(0, 6), j = L.slice().sort(), q = [ "offset" ], z = [ "timeZone" ], A = [ ...L, ...q ], U = [ ...A, ...z ], x = [ "era", "eraYear" ], $ = [ ...x, "year" ], G = [ "year" ], W = [ "monthCode" ], V = [ "month", ...W ], H = [ "day" ], J = [ ...V, ...G ], _ = [ ...W, ...G ], K = [ ...H, ...J ], Q = [ ...H, ...V ], X = [ ...H, ...W ], ee = P(L, 0), ne = bindArgs(requireType, "string"), te = bindArgs(requireType, "boolean"), oe = bindArgs(requireType, "number"), re = bindArgs(requireType, "function"), ie = F.map((e => e + "s")), ae = ie.slice().sort(), se = ie.slice(0, 6), ce = ie.slice(6), le = O(ie), ue = P(ie, 0), de = P(se, 0), fe = "smallestUnit", me = "unit", pe = "roundingIncrement", he = "fractionalSecondDigits", Te = "relativeTo", De = {
  constrain: 0,
  reject: 1
}, ge = Object.keys(De), Ie = bindArgs(refineUnitOption, fe), ye = bindArgs(refineUnitOption, "largestUnit"), Se = bindArgs(refineUnitOption, me), Ne = bindArgs(refineChoiceOption, "overflow", De), Oe = bindArgs(refineChoiceOption, "disambiguation", {
  compatible: 0,
  reject: 1,
  earlier: 2,
  later: 3
}), Pe = bindArgs(refineChoiceOption, "offset", {
  reject: 0,
  use: 1,
  prefer: 2,
  ignore: 3
}), ve = bindArgs(refineChoiceOption, "calendarName", {
  auto: 0,
  never: 1,
  critical: 2,
  always: 3
}), Me = bindArgs(refineChoiceOption, "timeZoneName", {
  auto: 0,
  never: 1,
  critical: 2
}), Fe = bindArgs(refineChoiceOption, "offset", {
  auto: 0,
  never: 1
}), be = bindArgs(refineChoiceOption, "roundingMode", {
  floor: 0,
  halfFloor: 1,
  ceil: 2,
  halfCeil: 3,
  trunc: 4,
  halfTrunc: 5,
  expand: 6,
  halfExpand: 7,
  halfEven: 8
}), we = "iso8601", Ee = "gregory", Ce = "japanese", Ze = {
  [Ee]: {
    bce: -1,
    ce: 0
  },
  [Ce]: {
    bce: -1,
    ce: 0,
    meiji: 1867,
    taisho: 1911,
    showa: 1925,
    heisei: 1988,
    reiwa: 2018
  },
  ethioaa: {
    era0: 0
  },
  ethiopic: {
    era0: 0,
    era1: 5500
  },
  coptic: {
    era0: -1,
    era1: 0
  },
  roc: {
    beforeroc: -1,
    minguo: 0
  },
  buddhist: {
    be: 0
  },
  islamic: {
    ah: 0
  },
  indian: {
    saka: 0
  },
  persian: {
    ap: 0
  }
}, ke = {
  bc: "bce",
  ad: "ce"
}, Ye = {
  chinese: 13,
  dangi: 13,
  hebrew: -6
}, Be = [ "isoNanosecond", "isoMicrosecond", "isoMillisecond", "isoSecond", "isoMinute", "isoHour" ], Re = [ "isoDay", "isoMonth", "isoYear" ], Le = [ ...Be, ...Re ], je = Re.slice().sort(), qe = Be.slice().sort(), ze = Le.slice().sort(), Ae = P(qe, 0), Ue = 1e8, xe = [ Ue, 0 ], $e = [ -Ue, 0 ], Ge = 275760, We = -271821, Ve = [ Math.floor, e => hasHalf(e) ? Math.floor(e) : Math.round(e), Math.ceil, e => hasHalf(e) ? Math.ceil(e) : Math.round(e), Math.trunc, e => hasHalf(e) ? Math.trunc(e) || 0 : Math.round(e), e => e < 0 ? Math.floor(e) : Math.ceil(e), e => Math.sign(e) * Math.round(Math.abs(e)) || 0, e => hasHalf(e) ? (e = Math.trunc(e) || 0) + e % 2 : Math.round(e) ], He = Intl.DateTimeFormat, Je = "numeric", _e = [ "timeZoneName" ], Ke = {
  month: Je,
  day: Je
}, Qe = {
  year: Je,
  month: Je
}, Xe = {
  ...Qe,
  day: Je
}, en = {
  hour: Je,
  minute: Je,
  second: Je
}, nn = {
  ...Xe,
  ...en
}, tn = {
  ...nn,
  timeZoneName: "short"
}, on = Object.keys(Ke), rn = Object.keys(Qe), an = [ ...Object.keys(Xe), "weekday", "dateStyle" ], sn = [ ...Object.keys(en), "dayPeriod", "timeStyle" ], cn = [ ...an, ...sn ], ln = [ ...cn, ..._e ], un = [ ..._e, ...sn ], dn = [ ..._e, ...an ], fn = [ ..._e, "day", "weekday", "dateStyle", ...sn ], mn = createOptionsTransformer(on, Ke, [ ..._e, "year", "weekday", "dateStyle", ...sn ]), pn = createOptionsTransformer(rn, Qe, fn), hn = createOptionsTransformer(an, Xe, un), Tn = createOptionsTransformer(cn, nn, _e), Dn = createOptionsTransformer(sn, en, dn), gn = createOptionsTransformer(cn, nn), In = createOptionsTransformer(ln, tn), yn = [ pn, isoDateFieldsToEpochNano, 1 ], Sn = [ mn, isoDateFieldsToEpochNano, 1 ], Nn = [ hn, isoDateFieldsToEpochNano ], On = [ Tn, isoDateFieldsToEpochNano ], Pn = [ Dn, (e, n) => getSingleInstantFor(queryNativeTimeZone(n.timeZone), {
  isoYear: An,
  isoMonth: 1,
  isoDay: 1,
  ...e
}) ], vn = [ gn, extractEpochNano ], Mn = [ (e, n, t) => {
  if (void 0 !== (e = In(e)).timeZone) {
    throw new TypeError("Forbidden timeZone");
  }
  return e.timeZone = ((e, n) => {
    const t = getId(e.timeZone);
    if (n && getId(n.timeZone) !== t) {
      throw new RangeError(m);
    }
    return t;
  })(n, t), e;
}, extractEpochNano ], Fn = {}, bn = "en-GB", wn = {
  era: toStringViaPrimitive,
  eraYear: toInteger,
  year: toInteger,
  month: toPositiveInteger,
  monthCode: toStringViaPrimitive,
  day: toPositiveInteger,
  ...P(L, toInteger),
  ...P(ie, toStrictInteger),
  offset: toStringViaPrimitive
}, En = bindArgs(((e, n, t) => {
  const o = {};
  for (let r = 0; r < e.length; r++) {
    o[n[r]] = t[e[r]];
  }
  return o;
}), L, Be), Cn = {
  dateAdd(e, n, t) {
    const o = refineOverflowOptions(t);
    let r, {years: i, months: a, weeks: s, days: c} = n;
    if (c += givenFieldsToDayTimeNano(n, 5, ie)[0], i || a) {
      let [n, t, s] = this.F(e);
      if (i) {
        const [e, r] = this.C(n, t);
        n += i, t = monthCodeNumberToMonth(e, r, this.o(n)), t = clampEntity("month", t, 1, this.i(n), o);
      }
      a && ([n, t] = this.L(n, t, a)), s = clampEntity("day", s, 1, this.l(n, t), o), 
      r = this.j(n, t, s);
    } else {
      if (!s && !c) {
        return e;
      }
      r = isoToEpochMilli(e);
    }
    return r += (s * $n + c) * b, checkIsoDateInBounds(epochMilliToIso(r));
  },
  dateUntil(e, n, t) {
    if (t <= 7) {
      let o = 0, r = diffDays(e, n);
      return 7 === t && ([o, r] = divModTrunc(r, $n)), {
        ...ue,
        weeks: o,
        days: r
      };
    }
    const o = this.F(e), r = this.F(n);
    let [i, a, s] = ((e, n, t, o, r, i, a) => {
      function updateYearMonth() {
        let [o, a] = e.C(n, t), [u, d] = e.C(r, i);
        s = r - n, c = e.i(r), l = s ? u - o || Number(d) - Number(a) : i - Math.min(t, c);
      }
      function updateYearMonthDay() {
        updateYearMonth(), u = e.l(r, i), d = a - Math.min(o, u);
      }
      let s, c, l, u, d;
      updateYearMonthDay();
      const f = Math.sign(d), m = Math.sign(s) || Math.sign(l) || f;
      if (m) {
        if (f === -m) {
          const n = u;
          [r, i] = e.L(r, i, -m), updateYearMonthDay(), d += m < 0 ? -n : u;
        }
        if (Math.sign(l) === -m) {
          const e = c;
          r -= m, updateYearMonth(), l += m < 0 ? -e : c;
        }
      }
      return [ s, l, d ];
    })(this, ...o, ...r);
    return 8 === t && (a += this.q(i, o[0]), i = 0), {
      ...ue,
      years: i,
      months: a,
      days: s
    };
  },
  dateFromFields(e, n) {
    const t = refineOverflowOptions(n), o = refineYear(this, e), r = refineMonth(this, e, o, t), i = refineDay(this, e, r, o, t);
    return createPlainDateSlots(checkIsoDateInBounds(this.B(o, r, i)), this.id || we);
  },
  yearMonthFromFields(e, n) {
    const t = refineOverflowOptions(n), o = refineYear(this, e), r = refineMonth(this, e, o, t);
    return createPlainYearMonthSlots(checkIsoYearMonthInBounds(this.B(o, r, 1)), this.id || we);
  },
  monthDayFromFields(e, n) {
    const t = refineOverflowOptions(n);
    let o, r, i, a, c, u = !this.id, {monthCode: d, year: f, month: m} = e;
    if (void 0 !== d) {
      [o, r] = parseMonthCode(d), c = getDefinedProp(e, "day");
      const n = this.k(o, r, c);
      if (!n) {
        throw new RangeError(l);
      }
      if ([i, a] = n, void 0 !== m && m !== a) {
        throw new RangeError(s);
      }
      u && (a = clampEntity("month", a, 1, xn, 1), c = clampEntity("day", c, 1, computeIsoDaysInMonth(void 0 !== f ? f : i, a), t));
    } else {
      i = void 0 === f && u ? Un : refineYear(this, e), a = refineMonth(this, e, i, t), 
      c = refineDay(this, e, a, i, t);
      const n = this.o(i);
      r = a === n, o = monthToMonthCodeNumber(a, n);
      const s = this.k(o, r, c);
      if (!s) {
        throw new RangeError(l);
      }
      [i, a] = s;
    }
    return createPlainMonthDaySlots(this.B(i, a, c), this.id || we);
  },
  fields(e) {
    return getCalendarEraOrigins(this) && e.includes("year") ? [ ...e, ...x ] : e;
  },
  mergeFields(e, n) {
    const t = Object.assign(Object.create(null), e);
    return spliceFields(t, n, V), getCalendarEraOrigins(this) && (spliceFields(t, n, $), 
    this.id === Ce && spliceFields(t, n, Q, x)), t;
  },
  inLeapYear(e) {
    const [n] = this.F(e);
    return this.U(n);
  },
  monthsInYear(e) {
    const [n] = this.F(e);
    return this.i(n);
  },
  daysInMonth(e) {
    const [n, t] = this.F(e);
    return this.l(n, t);
  },
  daysInYear(e) {
    const [n] = this.F(e);
    return this.$(n);
  },
  era(e) {
    return this.G(e)[0];
  },
  eraYear(e) {
    return this.G(e)[1];
  },
  monthCode(e) {
    const [n, t] = this.F(e), [o, r] = this.C(n, t);
    return ((e, n) => "M" + v(e) + (n ? "L" : ""))(o, r);
  },
  dayOfWeek: computeIsoDayOfWeek,
  weekOfYear(e) {
    return computeIsoWeekParts(e)[1];
  },
  yearOfWeek(e) {
    return computeIsoWeekParts(e)[0];
  },
  daysInWeek() {
    return $n;
  }
}, Zn = /^M(\d{2})(L?)$/, kn = createLazyGenerator((e => {
  function epochMilliToIntlFields(e) {
    return ((e, n) => ({
      ...parseIntlYear(e, n),
      month: e.month,
      day: parseInt(e.day)
    }))(hashIntlFormatParts(n, e), t);
  }
  const n = buildIntlFormat$1(e), t = computeCalendarIdBase(e);
  if (t !== computeCalendarIdBase(n.resolvedOptions().calendar)) {
    throw new RangeError((e => `Invalid Calendar: ${e}`)(e));
  }
  return {
    id: e,
    p: createIntlFieldCache(epochMilliToIntlFields),
    h: createIntlYearMonthCache(epochMilliToIntlFields)
  };
})), Yn = "UTC", Bn = 5184e3, Rn = isoArgsToEpochSec(1847), Ln = isoArgsToEpochSec((new Date).getUTCFullYear() + 10), jn = createLazyGenerator((e => e === Yn ? new FixedTimeZone(0, e) : new IntlTimeZone(e)));

class FixedTimeZone {
  constructor(e, n = formatOffsetNano(e)) {
    this.V = e, this.id = n;
  }
  getOffsetNanosecondsFor(e) {
    return this.V;
  }
  getPossibleInstantsFor(e) {
    return [ isoToEpochNanoWithOffset(e, this.V) ];
  }
  R(e, n) {}
}

class IntlTimeZone {
  constructor(e) {
    const n = new He(bn, {
      timeZone: e,
      era: "short",
      year: "numeric",
      month: "numeric",
      day: "numeric",
      hour: "numeric",
      minute: "numeric",
      second: "numeric"
    });
    this.id = n.resolvedOptions().timeZone, this.store = (e => {
      function getOffsetSec(e) {
        const i = clampNumber(e, o, r), [a, s] = computePeriod(i), c = n(a), l = n(s);
        return c === l ? c : pinch(t(a, s), c, l, e);
      }
      function pinch(n, t, o, r) {
        let i, a;
        for (;(void 0 === r || void 0 === (i = r < n[0] ? t : r >= n[1] ? o : void 0)) && (a = n[1] - n[0]); ) {
          const t = n[0] + Math.floor(a / 2);
          e(t) === o ? n[1] = t : n[0] = t + 1;
        }
        return i;
      }
      const n = createLazyGenerator(e), t = createLazyGenerator(createSplitTuple);
      let o = Rn, r = Ln;
      return {
        J(e) {
          const n = getOffsetSec(e - 86400), t = getOffsetSec(e + 86400), o = e - n, r = e - t;
          if (n === t) {
            return [ o ];
          }
          const i = getOffsetSec(o);
          return i === getOffsetSec(r) ? [ e - i ] : n > t ? [ o, r ] : [];
        },
        _: getOffsetSec,
        R(e, i) {
          const a = clampNumber(e, o, r);
          let [s, c] = computePeriod(a);
          const l = Bn * i, u = i < 0 ? () => c > o || (o = a, 0) : () => s < r || (r = a, 
          0);
          for (;u(); ) {
            const o = n(s), r = n(c);
            if (o !== r) {
              const n = t(s, c);
              pinch(n, o, r);
              const a = n[0];
              if ((compareNumbers(a, e) || 1) === i) {
                return a;
              }
            }
            s += l, c += l;
          }
        }
      };
    })((e => n => {
      const t = hashIntlFormatParts(e, n * w);
      return isoArgsToEpochSec(parseIntlYear(t, we).year, parseInt(t.month), parseInt(t.day), parseInt(t.hour), parseInt(t.minute), parseInt(t.second)) - n;
    })(n));
  }
  getOffsetNanosecondsFor(e) {
    return this.store._(epochNanoToSec(e)) * Z;
  }
  getPossibleInstantsFor(e) {
    const [n, t] = [ isoArgsToEpochSec((o = e).isoYear, o.isoMonth, o.isoDay, o.isoHour, o.isoMinute, o.isoSecond), o.isoMillisecond * C + o.isoMicrosecond * E + o.isoNanosecond ];
    var o;
    return this.store.J(n).map((e => checkEpochNanoInBounds(addDayTimeNanoAndNumber(numberToDayTimeNano(e, Z), t))));
  }
  R(e, n) {
    const [t, o] = (e => dayTimeNanoToNumberRemainder(e, Z))(e), r = this.store.R(t + (n > 0 || o ? 1 : 0), n);
    if (void 0 !== r) {
      return numberToDayTimeNano(r, Z);
    }
  }
}

const qn = /0+$/, zn = createLazyGenerator(((e, n) => {
  const {epochNanoseconds: t} = e, o = n.getOffsetNanosecondsFor(t);
  return {
    ...epochNanoToIso(t, o),
    offsetNanoseconds: o
  };
}), WeakMap), An = 1970, Un = 1972, xn = 12, $n = 7, Gn = createLazyGenerator((e => {
  const n = isoToEpochMilli(e);
  if (n < Wn) {
    return computeGregoryEraParts(e);
  }
  Vn || (Vn = buildIntlFormat$1(Ce));
  const t = hashIntlFormatParts(Vn, n), {era: o, eraYear: r} = parseIntlYear(t, Ce);
  return [ o, r ];
}), WeakMap), Wn = isoArgsToEpochMilli(1868, 9, 8);

let Vn;

const Hn = createLazyGenerator(computeDurationSign, WeakMap), Jn = {
  ...Cn,
  F(e) {
    return [ e.isoYear, e.isoMonth, e.isoDay ];
  },
  G(e) {
    return this.id === Ee ? computeGregoryEraParts(e) : this.id === Ce ? Gn(e) : [ void 0, void 0 ];
  },
  C(e, n) {
    return [ n, 0 ];
  },
  k(e, n) {
    if (!n) {
      return [ Un, e ];
    }
  },
  U: computeIsoInLeapYear,
  o() {},
  i: computeIsoMonthsInYear,
  q: e => e * xn,
  l: computeIsoDaysInMonth,
  $: computeIsoDaysInYear,
  dayOfYear: computeIsoDayOfYear,
  B(e, n, t) {
    return {
      isoYear: e,
      isoMonth: n,
      isoDay: t
    };
  },
  j: isoArgsToEpochMilli,
  L(e, n, t) {
    return e += divTrunc(t, xn), (n += modTrunc(t, xn)) < 1 ? (e--, n += xn) : n > xn && (e++, 
    n -= xn), [ e, n ];
  },
  year(e) {
    return e.isoYear;
  },
  month(e) {
    return e.isoMonth;
  },
  day: e => e.isoDay
}, _n = {
  ...Cn,
  F: computeIntlDateParts,
  G(e) {
    const n = this.p(e);
    return [ n.era, n.eraYear ];
  },
  C(e, n) {
    const t = computeIntlLeapMonth.call(this, e);
    return [ monthToMonthCodeNumber(n, t), t === n ];
  },
  k(e, n, t) {
    let [o, r, i] = computeIntlDateParts.call(this, {
      isoYear: Un,
      isoMonth: xn,
      isoDay: 31
    });
    const a = computeIntlLeapMonth.call(this, o), s = r === a;
    1 === (compareNumbers(e, monthToMonthCodeNumber(r, a)) || compareNumbers(Number(n), Number(s)) || compareNumbers(t, i)) && o--;
    for (let r = 0; r < 100; r++) {
      const i = o - r, a = computeIntlLeapMonth.call(this, i), s = monthCodeNumberToMonth(e, n, a);
      if (n === (s === a) && t <= computeIntlDaysInMonth.call(this, i, s)) {
        return [ i, s ];
      }
    }
  },
  U(e) {
    const n = computeIntlDaysInYear.call(this, e);
    return n > computeIntlDaysInYear.call(this, e - 1) && n > computeIntlDaysInYear.call(this, e + 1);
  },
  o: computeIntlLeapMonth,
  i: computeIntlMonthsInYear,
  q(e, n) {
    const t = n + e, o = Math.sign(e), r = o < 0 ? -1 : 0;
    let i = 0;
    for (let e = n; e !== t; e += o) {
      i += computeIntlMonthsInYear.call(this, e + r);
    }
    return i;
  },
  l: computeIntlDaysInMonth,
  $: computeIntlDaysInYear,
  dayOfYear(e) {
    const n = isoToEpochMilli({
      ...e,
      ...Ae
    }), {year: t} = this.p(e);
    return diffEpochMilliByDay(computeIntlEpochMilli.call(this, t), n);
  },
  B(e, n, t) {
    return checkIsoDateInBounds({
      ...epochMilliToIso(computeIntlEpochMilli.call(this, e, n, t))
    });
  },
  j: computeIntlEpochMilli,
  L(e, n, t) {
    if (t) {
      if (n += t, t < 0) {
        if (n < Number.MIN_SAFE_INTEGER) {
          throw new RangeError(D);
        }
        for (;n < 1; ) {
          n += computeIntlMonthsInYear.call(this, --e);
        }
      } else {
        if (n > Number.MAX_SAFE_INTEGER) {
          throw new RangeError(D);
        }
        let t;
        for (;n > (t = computeIntlMonthsInYear.call(this, e)); ) {
          n -= t, e++;
        }
      }
    }
    return [ e, n ];
  },
  year(e) {
    return this.p(e).year;
  },
  month(e) {
    const {year: n, month: t} = this.p(e), {m: o} = this.h(n);
    return o[t] + 1;
  },
  day(e) {
    return this.p(e).day;
  }
}, Kn = (Qn = Jn, Xn = _n, e => e === we ? Qn : e === Ee || e === Ce ? Object.assign(Object.create(Qn), {
  id: e
}) : Object.assign(Object.create(Xn), kn(e)));

var Qn, Xn;

const et = "([+−-])", nt = "(?:[.,](\\d{1,9}))?", tt = `(?:(?:${et}(\\d{6}))|(\\d{4}))-?(\\d{2})`, ot = "(\\d{2})(?::?(\\d{2})(?::?(\\d{2})" + nt + ")?)?", rt = et + ot, it = tt + "-?(\\d{2})(?:[T ]" + ot + "(Z|" + rt + ")?)?", at = "\\[(!?)([^\\]]*)\\]", st = `((?:${at})*)`, ct = createRegExp(tt + st), lt = createRegExp("(?:--)?(\\d{2})-?(\\d{2})" + st), ut = createRegExp(it + st), dt = createRegExp("T?" + ot + "(?:" + rt + ")?" + st), ft = createRegExp(rt), mt = new RegExp(at, "g"), pt = createRegExp(`${et}?P(\\d+Y)?(\\d+M)?(\\d+W)?(\\d+D)?(?:T(?:(\\d+)${nt}H)?(?:(\\d+)${nt}M)?(?:(\\d+)${nt}S)?)?`), ht = "PlainYearMonth", Tt = "PlainMonthDay", Dt = "PlainDate", gt = "PlainDateTime", It = "PlainTime", yt = "ZonedDateTime", St = "Instant", Nt = "Duration", Ot = {
  era(e) {
    if (void 0 !== e && "string" != typeof e) {
      throw new TypeError("Expected string or undefined");
    }
    return e;
  },
  eraYear(e) {
    if ("number" == typeof e) {
      requireNumberIsInteger(e);
    } else if (void 0 !== e) {
      throw new TypeError("Expected integer or undefined");
    }
    return e;
  },
  year: requireInteger,
  month: requirePositiveInteger,
  daysInMonth: requirePositiveInteger,
  daysInYear: requirePositiveInteger,
  inLeapYear: te,
  monthsInYear: requirePositiveInteger
}, Pt = {
  monthCode: ne
}, vt = {
  day: requirePositiveInteger
}, Mt = {
  dayOfWeek: requirePositiveInteger,
  dayOfYear: requirePositiveInteger,
  weekOfYear: requirePositiveInteger,
  yearOfWeek: requireInteger,
  daysInWeek: requirePositiveInteger
}, Ft = {
  ...Ot,
  ...Pt,
  ...vt,
  ...Mt
}, bt = {
  ...createCalendarFieldMethods(Ot, [ ht ]),
  ...createCalendarFieldMethods(Mt, []),
  ...createCalendarFieldMethods(Pt, [ ht, Tt ]),
  ...createCalendarFieldMethods(vt, [ Tt ])
}, wt = createCalendarGetters(Ft), Et = createCalendarGetters({
  ...Ot,
  ...Pt
}), Ct = createCalendarGetters({
  ...Pt,
  ...vt
}), Zt = {
  calendarId: e => getId(e.calendar)
}, kt = mapProps(((e, n) => function(t) {
  const {v: o} = this;
  return e(o[n](Ro(createPlainDateSlots(t, o))));
}), Ft), Yt = mapPropNames((e => n => n[e]), ie), Bt = mapPropNames(((e, n) => e => e[Be[n]]), L), Rt = {
  epochSeconds: e => epochNanoToSec(e.epochNanoseconds),
  epochMilliseconds: e => epochNanoToMilli(e.epochNanoseconds),
  epochMicroseconds: e => dayTimeNanoToBigInt(e.epochNanoseconds, E),
  epochNanoseconds: e => dayTimeNanoToBigInt(e.epochNanoseconds)
}, Lt = new WeakMap;

class DateTimeFormat extends He {
  constructor(e, n = {}) {
    super(e, n);
    const t = this.resolvedOptions(), o = pluckProps(Object.keys(n), t);
    Lt.set(this, ((e, n) => {
      const t = n.locale, o = createLazyGenerator((n => {
        const [o] = jt[n], r = o(e);
        return new He(t, r);
      }));
      return (e, t) => {
        const r = Uo(e), {O: i} = r || {};
        let a;
        if (void 0 !== t && (a = Uo(t), i !== (a || {}).O)) {
          throw new TypeError("Mismatching types for formatting");
        }
        if (i) {
          const e = jt[i];
          if (!e) {
            throw new TypeError((e => `Cannot format ${e}`)(i));
          }
          return [ o(i), ...toEpochMillis(e, n, r, a) ];
        }
        return [];
      };
    })(o, t));
  }
  format(e) {
    const n = Lt.get(this), [t, o] = n(e);
    return t ? t.format(o) : super.format(e);
  }
  formatToParts(e) {
    const n = Lt.get(this), [t, o] = n(e);
    return t ? t.formatToParts(o) : super.formatToParts(e);
  }
}

[ "formatRange", "formatRangeToParts" ].forEach((e => {
  const n = He.prototype[e];
  n && Object.defineProperties(DateTimeFormat.prototype, createPropDescriptors({
    [e](e, t) {
      const o = Lt.get(this), [r, i, a] = o(e, t);
      return r ? n.call(r, i, a) : n.call(this, e, t);
    }
  }));
}));

const jt = {
  PlainYearMonth: yn,
  PlainMonthDay: Sn,
  PlainDate: Nn,
  PlainDateTime: On,
  PlainTime: Pn,
  Instant: vn
}, qt = createFormatPrepper(yn), zt = createFormatPrepper(Sn), At = createFormatPrepper(Nn), Ut = createFormatPrepper(On), xt = createFormatPrepper(Pn), $t = createFormatPrepper(vn), Gt = createFormatPrepper(Mn), [Wt, Vt, Ht] = createSlotClass(Tt, bindArgs(((e, n, t, o = we, r = Un) => {
  const i = toInteger(n), a = toInteger(t), s = e(o);
  return createPlainMonthDaySlots(checkIsoDateInBounds(checkIsoDateFields({
    isoYear: toInteger(r),
    isoMonth: i,
    isoDay: a
  })), s);
}), refineCalendarSlot), {
  ...Zt,
  ...Ct
}, {
  with(e, n, t) {
    return Vt(((e, n, t, o, r) => {
      const i = copyOptions(r);
      return ((e, n, t, o) => {
        const r = mergeCalendarFields(e, n, t, K);
        return e.monthDayFromFields(r, o);
      })(e(n.calendar), t, o, i);
    })(To, e, this, rejectInvalidBag(n), t));
  },
  equals(e, n) {
    return !compareIsoDateFields(t = e, o = toPlainMonthDaySlots(n)) && isIdLikeEqual(t.calendar, o.calendar);
    var t, o;
  },
  toString: formatPlainMonthDayIso,
  toJSON: e => formatPlainMonthDayIso(e),
  toLocaleString(e, n, t) {
    const [o, r] = zt(n, t, e);
    return o.format(r);
  },
  toPlainDate(e, n) {
    return Ro(((e, n, t, o) => ((e, n, t) => convertToIso(e, n, X, requireObjectlike(t), G))(ho(n.calendar), t, o))(0, e, this, n));
  },
  getISOFields: removeBranding,
  getCalendar: getCalendarFromSlots,
  valueOf: neverValueOf
}, {
  from: (e, n) => Vt(toPlainMonthDaySlots(e, n))
}), [Jt, _t, Kt] = createSlotClass(ht, bindArgs(((e, n, t, o = we, r = 1) => {
  const i = toInteger(n), a = toInteger(t), s = e(o);
  return createPlainYearMonthSlots(checkIsoYearMonthInBounds(checkIsoDateFields({
    isoYear: i,
    isoMonth: a,
    isoDay: toInteger(r)
  })), s);
}), refineCalendarSlot), {
  ...Zt,
  ...Et
}, {
  with(e, n, t) {
    return _t(((e, n, t, o, r) => {
      const i = copyOptions(r);
      return createPlainYearMonthSlots(((e, n, t, o) => {
        const r = mergeCalendarFields(e, n, t, J);
        return e.yearMonthFromFields(r, o);
      })(e(n.calendar), t, o, i));
    })(po, e, this, rejectInvalidBag(n), t));
  },
  add: (e, n, t) => _t(movePlainYearMonth(Io, e, toDurationSlots(n), t)),
  subtract: (e, n, t) => _t(movePlainYearMonth(Io, e, toDurationSlots(n), t, 1)),
  until: (e, n, t) => Co(diffPlainYearMonth(yo, e, toPlainYearMonthSlots(n), t)),
  since: (e, n, t) => Co(diffPlainYearMonth(yo, e, toPlainYearMonthSlots(n), t, 1)),
  equals(e, n) {
    return !compareIsoDateFields(t = e, o = toPlainYearMonthSlots(n)) && isIdLikeEqual(t.calendar, o.calendar);
    var t, o;
  },
  toString: formatPlainYearMonthIso,
  toJSON: e => formatPlainYearMonthIso(e),
  toLocaleString(e, n, t) {
    const [o, r] = qt(n, t, e);
    return o.format(r);
  },
  toPlainDate(e, n) {
    return Ro(((e, n, t, o) => ((e, n, t) => convertToIso(e, n, _, requireObjectlike(t), H))(ho(n.calendar), t, o))(0, e, this, n));
  },
  getISOFields: removeBranding,
  getCalendar: getCalendarFromSlots,
  valueOf: neverValueOf
}, {
  from: (e, n) => _t(toPlainYearMonthSlots(e, n)),
  compare: (e, n) => compareIsoDateFields(toPlainYearMonthSlots(e), toPlainYearMonthSlots(n))
}), Qt = {
  fields(e, n, t) {
    return [ ...n.call(e, t) ];
  }
}, Xt = {
  dateFromFields(e, n, t, o) {
    return Lo(n.call(e, Object.assign(Object.create(null), t), o));
  },
  ...Qt
}, eo = {
  yearMonthFromFields(e, n, t, o) {
    return Kt(n.call(e, Object.assign(Object.create(null), t), o));
  },
  ...Qt
}, no = {
  monthDayFromFields(e, n, t, o) {
    return Ht(n.call(e, Object.assign(Object.create(null), t), o));
  },
  ...Qt
}, to = {
  mergeFields(e, n, t, o) {
    return requireObjectlike(n.call(e, Object.assign(Object.create(null), t), Object.assign(Object.create(null), o)));
  }
}, oo = {
  ...Xt,
  ...to
}, ro = {
  ...eo,
  ...to
}, io = {
  ...no,
  ...to
}, ao = {
  dateAdd(e, n, t, o, r) {
    return Lo(n.call(e, Ro(createPlainDateSlots(t, e)), Co(createDurationSlots(o)), r));
  }
}, so = {
  ...ao,
  dateUntil(e, n, t, o, r, i) {
    return Zo(n.call(e, Ro(createPlainDateSlots(t, e)), Ro(createPlainDateSlots(o, e)), Object.assign(Object.create(null), i, {
      largestUnit: F[r]
    })));
  }
}, co = {
  ...ao,
  day: dayAdapter
}, lo = {
  ...so,
  day: dayAdapter
}, uo = createCompoundOpsCreator(eo), fo = createCompoundOpsCreator(Xt), mo = createCompoundOpsCreator(no), po = createCompoundOpsCreator(ro), ho = createCompoundOpsCreator(oo), To = createCompoundOpsCreator(io), Do = createCompoundOpsCreator(ao), go = createCompoundOpsCreator(so), Io = createCompoundOpsCreator(co), yo = createCompoundOpsCreator(lo), [So, No] = createSlotClass("TimeZone", (e => {
  const n = queryNativeTimeZone(ne(e));
  return {
    O: "TimeZone",
    id: n.id,
    P: n
  };
}), {
  id: e => e.id
}, {
  toString: e => e.id,
  toJSON: e => e.id,
  getPossibleInstantsFor: ({P: e}, n) => e.getPossibleInstantsFor(toPlainDateTimeSlots(n)).map((e => Mo(createInstantSlots(e)))),
  getOffsetNanosecondsFor: ({P: e}, n) => e.getOffsetNanosecondsFor(toInstantSlots(n).epochNanoseconds),
  getOffsetStringFor(e, n) {
    const t = toInstantSlots(n).epochNanoseconds;
    return formatOffsetNano(createAdapterOps(this, wo).getOffsetNanosecondsFor(t));
  },
  getPlainDateTimeFor(e, n, t = we) {
    const o = toInstantSlots(n).epochNanoseconds, r = createAdapterOps(this, wo).getOffsetNanosecondsFor(o);
    return Yo(createPlainDateTimeSlots(epochNanoToIso(o, r), refineCalendarSlot(t)));
  },
  getInstantFor(e, n, t) {
    const o = toPlainDateTimeSlots(n), r = refineEpochDisambigOptions(t), i = createAdapterOps(this);
    return Mo(createInstantSlots(getSingleInstantFor(i, o, r)));
  },
  getNextTransition: ({P: e}, n) => getImplTransition(1, e, n),
  getPreviousTransition: ({P: e}, n) => getImplTransition(-1, e, n),
  equals(e, n) {
    return isTimeZoneSlotsEqual(this, refineTimeZoneSlot(n));
  }
}, {
  from(e) {
    const n = refineTimeZoneSlot(e);
    return "string" == typeof n ? new So(n) : n;
  }
}), [Oo, Po] = createSlotClass(yt, bindArgs(((e, n, t, o, r = we) => createZonedDateTimeSlots(checkEpochNanoInBounds(bigIntToDayTimeNano(toBigInt(t))), n(o), e(r))), refineCalendarSlot, refineTimeZoneSlot), {
  ...Rt,
  ...Zt,
  ...adaptToIsoFields(wt),
  ...adaptToIsoFields(Bt),
  hoursInDay: e => ((e, n) => {
    const t = createTimeZoneOps(n.timeZone);
    return computeNanosecondsInDay(t, zn(n, t)) / Y;
  })(0, e),
  offsetNanoseconds: e => slotsToIsoFields(e).offsetNanoseconds,
  offset: e => formatOffsetNano(slotsToIsoFields(e).offsetNanoseconds),
  timeZoneId: e => getId(e.timeZone)
}, {
  with(e, n, t) {
    return Po(((e, n, t, o, r, i) => {
      const a = copyOptions(i), {calendar: s, timeZone: c} = t;
      return createZonedDateTimeSlots(((e, n, t, o, r) => {
        const i = mergeCalendarFields(e, t, o, K, A, q), [a, s, c] = refineZonedFieldOptions(r, 2);
        return getMatchingInstantFor(n, {
          ...e.dateFromFields(i, overrideOverflowOptions(r, a)),
          ...refineTimeBag(i, a)
        }, parseOffsetNano(i.offset), s, c);
      })(e(s), n(c), o, r, a), c, s);
    })(ho, createTimeZoneOps, e, this, rejectInvalidBag(n), t));
  },
  withPlainTime: (e, n) => Po(((e, n, t = Ae) => {
    const o = n.timeZone, r = e(o), i = {
      ...zn(n, r),
      ...t
    };
    return createZonedDateTimeSlots(getMatchingInstantFor(r, i, i.offsetNanoseconds, 2), o, n.calendar);
  })(createTimeZoneOps, e, optionalToPlainTimeFields(n))),
  withPlainDate: (e, n) => Po(((e, n, t) => {
    const o = n.timeZone, r = e(o), i = {
      ...zn(n, r),
      ...t
    }, a = getPreferredCalendarSlot(n.calendar, t.calendar);
    return createZonedDateTimeSlots(getMatchingInstantFor(r, i, i.offsetNanoseconds, 2), o, a);
  })(createTimeZoneOps, e, toPlainDateSlots(n))),
  withTimeZone: (e, n) => Po(((e, n) => ({
    ...e,
    timeZone: n
  }))(e, refineTimeZoneSlot(n))),
  withCalendar: (e, n) => Po(slotsWithCalendar(e, refineCalendarSlot(n))),
  add: (e, n, t) => Po(moveZonedDateTime(Do, createTimeZoneOps, e, toDurationSlots(n), t)),
  subtract: (e, n, t) => Po(moveZonedDateTime(Do, createTimeZoneOps, e, toDurationSlots(n), t, 1)),
  until: (e, n, t) => Co(createDurationSlots(diffZonedDateTimes(go, createTimeZoneOps, e, toZonedDateTimeSlots(n), t))),
  since: (e, n, t) => Co(createDurationSlots(diffZonedDateTimes(go, createTimeZoneOps, e, toZonedDateTimeSlots(n), t, 1))),
  round: (e, n) => Po(((e, n, t) => {
    let {epochNanoseconds: o, timeZone: r, calendar: i} = n;
    const [a, s, c] = refineRoundOptions(t);
    if (0 === a && 1 === s) {
      return n;
    }
    const l = e(r), u = l.getOffsetNanosecondsFor(o);
    let d = {
      ...epochNanoToIso(o, u),
      calendar: i
    };
    return d = {
      calendar: i,
      ...roundDateTime(d, a, s, c, l)
    }, o = getMatchingInstantFor(l, d, u, 2, 0, 1), createZonedDateTimeSlots(o, r, i);
  })(createTimeZoneOps, e, n)),
  startOfDay: e => Po(((e, n) => {
    let {epochNanoseconds: t, timeZone: o, calendar: r} = n;
    const i = e(o);
    return t = getMatchingInstantFor(i, {
      ...zn(n, i),
      ...Ae
    }, void 0, 0, 0, 1), createZonedDateTimeSlots(t, o, r);
  })(createTimeZoneOps, e)),
  equals(e, n) {
    return !compareZonedDateTimes(t = e, o = toZonedDateTimeSlots(n)) && isTimeZoneSlotsEqual(t.timeZone, o.timeZone) && isIdLikeEqual(t.calendar, o.calendar);
    var t, o;
  },
  toString: (e, n) => formatZonedDateTimeIso(createSimpleTimeZoneOps, e, n),
  toJSON: e => formatZonedDateTimeIso(createSimpleTimeZoneOps, e),
  toLocaleString(e, n, t = {}) {
    const [o, r] = Gt(n, t, e);
    return o.format(r);
  },
  toInstant: e => Mo(createInstantSlots(e.epochNanoseconds)),
  toPlainDate: e => Ro(zonedDateTimeToPlainDate(createSimpleTimeZoneOps, e)),
  toPlainTime: e => qo(zonedDateTimeToPlainTime(createSimpleTimeZoneOps, e)),
  toPlainDateTime: e => Yo(zonedDateTimeToPlainDateTime(createSimpleTimeZoneOps, e)),
  toPlainYearMonth(e) {
    return _t(convertToPlainYearMonth(uo(e.calendar), this));
  },
  toPlainMonthDay(e) {
    return Vt(convertToPlainMonthDay(mo(e.calendar), this));
  },
  getISOFields: e => ((e, n) => {
    const t = zn(n, createSimpleTimeZoneOps(n.timeZone));
    return {
      calendar: n.calendar,
      ...pluckProps(ze, t),
      offset: formatOffsetNano(t.offsetNanoseconds),
      timeZone: n.timeZone
    };
  })(0, e),
  getCalendar: getCalendarFromSlots,
  getTimeZone: ({timeZone: e}) => "string" == typeof e ? new So(e) : e,
  valueOf: neverValueOf
}, {
  from: (e, n) => Po(toZonedDateTimeSlots(e, n)),
  compare: (e, n) => compareZonedDateTimes(toZonedDateTimeSlots(e), toZonedDateTimeSlots(n))
}), [vo, Mo, Fo] = createSlotClass(St, (e => createInstantSlots(checkEpochNanoInBounds(bigIntToDayTimeNano(toBigInt(e))))), Rt, {
  add: (e, n) => Mo(moveInstant(e, toDurationSlots(n))),
  subtract: (e, n) => Mo(moveInstant(e, toDurationSlots(n), 1)),
  until: (e, n, t) => Co(diffInstants(e, toInstantSlots(n), t)),
  since: (e, n, t) => Co(diffInstants(e, toInstantSlots(n), t, 1)),
  round: (e, n) => Mo(((e, n) => {
    const [t, o, r] = refineRoundOptions(n, 5, 1);
    return createInstantSlots(roundDayTimeNano(e.epochNanoseconds, t, o, r, 1));
  })(e, n)),
  equals(e, n) {
    return !compareInstants(e, toInstantSlots(n));
  },
  toString: (e, n) => formatInstantIso(refineTimeZoneSlot, createSimpleTimeZoneOps, e, n),
  toJSON: e => formatInstantIso(refineTimeZoneSlot, createSimpleTimeZoneOps, e),
  toLocaleString(e, n, t) {
    const [o, r] = $t(n, t, e);
    return o.format(r);
  },
  toZonedDateTimeISO: (e, n) => Po(instantToZonedDateTime(e, refineTimeZoneSlot(n))),
  toZonedDateTime(e, n) {
    const t = requireObjectlike(n);
    return Po(instantToZonedDateTime(e, refineTimeZoneSlot(t.timeZone), refineCalendarSlot(t.calendar)));
  },
  valueOf: neverValueOf
}, {
  from: e => Mo(toInstantSlots(e)),
  fromEpochSeconds: e => Mo((e => createInstantSlots(checkEpochNanoInBounds(numberToDayTimeNano(e, Z))))(e)),
  fromEpochMilliseconds: e => Mo((e => createInstantSlots(checkEpochNanoInBounds(numberToDayTimeNano(e, C))))(e)),
  fromEpochMicroseconds: e => Mo((e => createInstantSlots(checkEpochNanoInBounds(bigIntToDayTimeNano(toBigInt(e), E))))(e)),
  fromEpochNanoseconds: e => Mo((e => createInstantSlots(checkEpochNanoInBounds(bigIntToDayTimeNano(toBigInt(e)))))(e)),
  compare: (e, n) => compareInstants(toInstantSlots(e), toInstantSlots(n))
}), bo = {
  getOffsetNanosecondsFor: adapterGetOffsetNanosecondsFor,
  getPossibleInstantsFor(e, n, t) {
    return [ ...n.call(e, Yo(createPlainDateTimeSlots(t, we))) ].map((e => Fo(e).epochNanoseconds));
  }
}, wo = {
  getOffsetNanosecondsFor: adapterGetOffsetNanosecondsFor
}, [Eo, Co, Zo] = createSlotClass(Nt, ((e = 0, n = 0, t = 0, o = 0, r = 0, i = 0, a = 0, s = 0, c = 0, l = 0) => createDurationSlots(checkDurationFields(mapProps(toStrictInteger, zipProps(ie, [ e, n, t, o, r, i, a, s, c, l ]))))), {
  ...Yt,
  blank: e => !Hn(e),
  sign: e => Hn(e)
}, {
  with: (e, n) => Co(((e, n) => {
    return createDurationSlots((t = e, o = n, checkDurationFields({
      ...t,
      ...refineFields(o, ae)
    })));
    var t, o;
  })(e, n)),
  add: (e, n, t) => Co(addDurations(refinePublicRelativeTo, go, createTimeZoneOps, e, toDurationSlots(n), t)),
  subtract: (e, n, t) => Co(addDurations(refinePublicRelativeTo, go, createTimeZoneOps, e, toDurationSlots(n), t, 1)),
  negated: e => Co(negateDuration(e)),
  abs: e => Co((e => {
    return createDurationSlots(-1 === Hn(n = e) ? negateDurationFields(n) : n);
    var n;
  })(e)),
  round: (e, n) => Co(((e, n, t, o, r) => {
    const i = getLargestDurationUnit(o), [a, s, c, l, u] = ((e, n, t) => {
      e = normalizeUnitNameOptions(e, fe);
      let o = ye(e);
      const r = t(e[Te]);
      let i = parseRoundingIncInteger(e);
      const a = be(e, 7);
      let s = Ie(e);
      if (void 0 === o && void 0 === s) {
        throw new RangeError("Required smallestUnit or largestUnit");
      }
      return null == s && (s = 0), null == o && (o = Math.max(s, n)), checkLargestSmallestUnit(o, s), 
      i = refineRoundingInc(i, s, 1), [ o, s, i, a, r ];
    })(r, i, e), f = Math.max(i, a);
    if (f < 6 || 6 === f && (!u || !u.epochNanoseconds)) {
      return createDurationSlots(((e, n, t, o, r) => ({
        ...ue,
        ...balanceDayTimeDuration(e, n, t, o, r)
      }))(o, a, s, c, l));
    }
    if (!u) {
      throw new RangeError(I);
    }
    const m = createMarkerSystem(n, t, u);
    let p = 0;
    o.weeks && 7 === s && (p = o.weeks, o = {
      ...o,
      weeks: 0
    });
    let [h, T] = spanDuration(o, void 0, a, ...m);
    const D = Hn(o), g = Hn(h);
    if (D && g && D !== g) {
      throw new RangeError(d);
    }
    return !g || 0 === s && 1 === c || (h = roundRelativeDuration(h, T, a, s, c, l, ...m)), 
    h.weeks += p, createDurationSlots(h);
  })(refinePublicRelativeTo, go, createTimeZoneOps, e, n)),
  total: (e, n) => ((e, n, t, o, r) => {
    const i = getLargestDurationUnit(o), [a, s] = ((e, n) => {
      const t = n((e = normalizeUnitNameOptions(e, me))[Te]);
      let o = Se(e);
      return o = requirePropDefined(me, o), [ o, t ];
    })(r, e), c = Math.max(a, i);
    if (c < 6 || 6 === c && (!s || !s.epochNanoseconds)) {
      return ((e, n) => totalDayTimeNano(durationFieldsToDayTimeNano(e, 6), n))(o, a);
    }
    if (!s) {
      throw new RangeError(I);
    }
    const l = createMarkerSystem(n, t, s);
    return ((e, n, t, o, r, i) => {
      const a = Hn(e), [s, c] = clampRelativeDuration(clearDurationFields(e, t - 1), t, a, o, r, i), l = computeEpochNanoFrac(s, c, n);
      return e[ie[t]] + l * a;
    })(...spanDuration(o, void 0, a, ...l), a, ...l);
  })(refinePublicRelativeTo, go, createTimeZoneOps, e, n),
  toString: formatDurationIso,
  toLocaleString(e, n, t) {
    return new Intl.DurationFormat(n, t).format(this);
  },
  toJSON: e => formatDurationIso(e),
  valueOf: neverValueOf
}, {
  from: e => Co(toDurationSlots(e)),
  compare: (e, n, t) => ((e, n, t, o, r, i) => {
    const a = e(normalizeOptions(i).relativeTo), s = Math.max(getLargestDurationUnit(o), getLargestDurationUnit(r));
    if (allFieldsEqual(ie, o, r)) {
      return 0;
    }
    if (s < 6 || 6 === s && (!a || !a.epochNanoseconds)) {
      return compareDayTimeNanos(givenFieldsToDayTimeNano(o, 6, ie), givenFieldsToDayTimeNano(r, 6, ie));
    }
    if (!a) {
      throw new RangeError(I);
    }
    const [c, l, u] = createMarkerSystem(n, t, a);
    return compareDayTimeNanos(l(u(c, o)), l(u(c, r)));
  })(refinePublicRelativeTo, go, createTimeZoneOps, toDurationSlots(e), toDurationSlots(n), t)
}), [ko, Yo] = createSlotClass(gt, bindArgs(((e, n, t, o, r = 0, i = 0, a = 0, s = 0, c = 0, l = 0, u = we) => createPlainDateTimeSlots(checkIsoDateTimeInBounds(checkIsoDateTimeFields(mapProps(toInteger, zipProps(Le, [ n, t, o, r, i, a, s, c, l ])))), e(u))), refineCalendarSlot), {
  ...Zt,
  ...wt,
  ...Bt
}, {
  with(e, n, t) {
    return Yo(((e, n, t, o, r) => {
      const i = copyOptions(r);
      return createPlainDateTimeSlots(((e, n, t, o) => {
        const r = mergeCalendarFields(e, n, t, K, L), i = refineOverflowOptions(o);
        return checkIsoDateTimeInBounds({
          ...e.dateFromFields(r, overrideOverflowOptions(o, i)),
          ...refineTimeBag(r, i)
        });
      })(e(n.calendar), t, o, i));
    })(ho, e, this, rejectInvalidBag(n), t));
  },
  withPlainTime: (e, n) => Yo(((e, n = Ae) => createPlainDateTimeSlots({
    ...e,
    ...n
  }))(e, optionalToPlainTimeFields(n))),
  withPlainDate(e, n) {
    return Yo((t = e, o = toPlainDateSlots(n), createPlainDateTimeSlots({
      ...t,
      ...o
    }, getPreferredCalendarSlot(t.calendar, o.calendar))));
    var t, o;
  },
  withCalendar: (e, n) => Yo(slotsWithCalendar(e, refineCalendarSlot(n))),
  add: (e, n, t) => Yo(movePlainDateTime(Do, e, toDurationSlots(n), t)),
  subtract: (e, n, t) => Yo(movePlainDateTime(Do, e, toDurationSlots(n), t, 1)),
  until: (e, n, t) => Co(diffPlainDateTimes(go, e, toPlainDateTimeSlots(n), t)),
  since: (e, n, t) => Co(diffPlainDateTimes(go, e, toPlainDateTimeSlots(n), t, 1)),
  round: (e, n) => Yo(((e, n) => createPlainDateTimeSlots(roundDateTime(e, ...refineRoundOptions(n)), e.calendar))(e, n)),
  equals(e, n) {
    return !compareIsoDateTimeFields(t = e, o = toPlainDateTimeSlots(n)) && isIdLikeEqual(t.calendar, o.calendar);
    var t, o;
  },
  toString: (e, n) => formatPlainDateTimeIso(e, n),
  toJSON: e => formatPlainDateTimeIso(e),
  toLocaleString(e, n, t) {
    const [o, r] = Ut(n, t, e);
    return o.format(r);
  },
  toZonedDateTime: (e, n, t) => Po(((e, n, t, o) => createZonedDateTimeSlots(((e, n, t, o) => {
    const r = refineEpochDisambigOptions(o);
    return checkEpochNanoInBounds(getSingleInstantFor(e(n), t, r));
  })(e, t, n, o), t, n.calendar))(createTimeZoneOps, e, refineTimeZoneSlot(n), t)),
  toPlainDate: e => Ro(createPlainDateSlots(e)),
  toPlainYearMonth(e) {
    return _t(((e, n, t) => {
      const o = uo(n.calendar);
      return createPlainYearMonthSlots({
        ...n,
        ...convertToPlainYearMonth(o, t)
      });
    })(0, e, this));
  },
  toPlainMonthDay(e) {
    return Vt(convertToPlainMonthDay(mo(e.calendar), this));
  },
  toPlainTime: e => qo(createPlainTimeSlots(e)),
  getISOFields: removeBranding,
  getCalendar: getCalendarFromSlots,
  valueOf: neverValueOf
}, {
  from: (e, n) => Yo(toPlainDateTimeSlots(e, n)),
  compare: (e, n) => compareIsoDateTimeFields(toPlainDateTimeSlots(e), toPlainDateTimeSlots(n))
}), [Bo, Ro, Lo] = createSlotClass(Dt, bindArgs(((e, n, t, o, r = we) => createPlainDateSlots(checkIsoDateInBounds(checkIsoDateFields(mapProps(toInteger, {
  isoYear: n,
  isoMonth: t,
  isoDay: o
}))), e(r))), refineCalendarSlot), {
  ...Zt,
  ...wt
}, {
  with(e, n, t) {
    return Ro(((e, n, t, o, r) => {
      const i = copyOptions(r);
      return ((e, n, t, o) => {
        const r = mergeCalendarFields(e, n, t, K);
        return e.dateFromFields(r, o);
      })(e(n.calendar), t, o, i);
    })(ho, e, this, rejectInvalidBag(n), t));
  },
  withCalendar: (e, n) => Ro(slotsWithCalendar(e, refineCalendarSlot(n))),
  add: (e, n, t) => Ro(movePlainDate(Do, e, toDurationSlots(n), t)),
  subtract: (e, n, t) => Ro(movePlainDate(Do, e, toDurationSlots(n), t, 1)),
  until: (e, n, t) => Co(diffPlainDates(go, e, toPlainDateSlots(n), t)),
  since: (e, n, t) => Co(diffPlainDates(go, e, toPlainDateSlots(n), t, 1)),
  equals(e, n) {
    return !compareIsoDateFields(t = e, o = toPlainDateSlots(n)) && isIdLikeEqual(t.calendar, o.calendar);
    var t, o;
  },
  toString: formatPlainDateIso,
  toJSON: e => formatPlainDateIso(e),
  toLocaleString(e, n, t) {
    const [o, r] = At(n, t, e);
    return o.format(r);
  },
  toZonedDateTime(e, n) {
    const t = !isObjectLike(n) || n instanceof So ? {
      timeZone: n
    } : n;
    return Po(((e, n, t, o, r) => {
      const i = refineTimeZoneSlot(r.timeZone), a = r.plainTime, s = void 0 !== a ? n(a) : Ae;
      return createZonedDateTimeSlots(getSingleInstantFor(t(i), {
        ...o,
        ...s
      }), i, o.calendar);
    })(0, toPlainTimeSlots, createTimeZoneOps, e, t));
  },
  toPlainDateTime: (e, n) => Yo(((e, n = Ae) => createPlainDateTimeSlots(checkIsoDateTimeInBounds({
    ...e,
    ...n
  })))(e, optionalToPlainTimeFields(n))),
  toPlainYearMonth(e) {
    return _t(convertToPlainYearMonth(uo(e.calendar), this));
  },
  toPlainMonthDay(e) {
    return Vt(convertToPlainMonthDay(mo(e.calendar), this));
  },
  getISOFields: removeBranding,
  getCalendar: getCalendarFromSlots,
  valueOf: neverValueOf
}, {
  from: (e, n) => Ro(toPlainDateSlots(e, n)),
  compare: (e, n) => compareIsoDateFields(toPlainDateSlots(e), toPlainDateSlots(n))
}), [jo, qo] = createSlotClass(It, ((e = 0, n = 0, t = 0, o = 0, r = 0, i = 0) => createPlainTimeSlots(constrainIsoTimeFields(mapProps(toInteger, zipProps(Be, [ e, n, t, o, r, i ])), 1))), Bt, {
  with(e, n, t) {
    return qo(((e, n, t) => createPlainTimeSlots(((e, n, t) => {
      const o = refineOverflowOptions(t);
      return refineTimeBag({
        ...pluckProps(j, e),
        ...refineFields(n, j)
      }, o);
    })(e, n, t)))(this, rejectInvalidBag(n), t));
  },
  add: (e, n) => qo(movePlainTime(e, toDurationSlots(n))),
  subtract: (e, n) => qo(movePlainTime(e, toDurationSlots(n), 1)),
  until: (e, n, t) => Co(diffPlainTimes(e, toPlainTimeSlots(n), t)),
  since: (e, n, t) => Co(diffPlainTimes(e, toPlainTimeSlots(n), t, 1)),
  round: (e, n) => qo(((e, n) => createPlainTimeSlots(((e, n, t, o) => roundTimeToNano(e, computeNanoInc(n, t), o)[0])(e, ...refineRoundOptions(n, 5))))(e, n)),
  equals(e, n) {
    return !compareIsoTimeFields(e, toPlainTimeSlots(n));
  },
  toString: formatPlainTimeIso,
  toJSON: e => formatPlainTimeIso(e),
  toLocaleString(e, n, t) {
    const [o, r] = xt(n, t, e);
    return o.format(r);
  },
  toZonedDateTime: (e, n) => Po(((e, n, t, o, r) => {
    const i = toPlainDateSlots(r.plainDate), a = e(r.timeZone);
    return createZonedDateTimeSlots(getSingleInstantFor(t(a), {
      ...i,
      ...o
    }), a, i.calendar);
  })(refineTimeZoneSlot, 0, createTimeZoneOps, e, n)),
  toPlainDateTime(e, n) {
    return Yo((t = e, o = toPlainDateSlots(n), createPlainDateTimeSlots(checkIsoDateTimeInBounds({
      ...t,
      ...o
    }))));
    var t, o;
  },
  getISOFields: removeBranding,
  valueOf: neverValueOf
}, {
  from: (e, n) => qo(toPlainTimeSlots(e, n)),
  compare: (e, n) => compareIsoTimeFields(toPlainTimeSlots(e), toPlainTimeSlots(n))
}), zo = createProtocolChecker(Object.keys(bo)), Ao = new WeakMap, Uo = Ao.get.bind(Ao), xo = Ao.set.bind(Ao), $o = {
  toString: e => e.id,
  toJSON: e => e.id,
  ...bt,
  dateAdd: ({id: e, P: n}, t, o, r) => Ro(createPlainDateSlots(n.dateAdd(toPlainDateSlots(t), toDurationSlots(o), r), e)),
  dateUntil: ({P: e}, n, t, o) => Co(createDurationSlots(e.dateUntil(toPlainDateSlots(n), toPlainDateSlots(t), (e => (e = normalizeOptions(e), 
  ye(e, 9, 6, 1)))(o)))),
  dateFromFields: ({id: e, P: n}, t, o) => Ro(refinePlainDateBag(n, t, o, e === we ? [ "year", "day" ] : [])),
  yearMonthFromFields: ({id: e, P: n}, t, o) => _t(refinePlainYearMonthBag(n, t, o, e === we ? G : [])),
  monthDayFromFields: ({id: e, P: n}, t, o) => Vt(refinePlainMonthDayBag(n, 0, t, o, e === we ? H : [])),
  fields({P: e}, n) {
    const t = new Set(K), o = [];
    for (const e of n) {
      if (ne(e), !t.has(e)) {
        throw new RangeError(forbiddenField(e));
      }
      t.delete(e), o.push(e);
    }
    return e.fields(o);
  },
  mergeFields: ({P: e}, n, t) => e.mergeFields(excludeUndefinedProps(requireNonNullish(n)), excludeUndefinedProps(requireNonNullish(t)))
}, [Go] = createSlotClass("Calendar", (e => ({
  O: "Calendar",
  id: e = normalizeCalendarId(ne(e)),
  P: Kn(e)
})), {
  id: e => e.id
}, $o, {
  from(e) {
    const n = refineCalendarSlot(e);
    return "string" == typeof n ? new Go(n) : n;
  }
}), Wo = createProtocolChecker(Object.keys($o).slice(4));

let Vo;

const Ho = Object.defineProperties({}, {
  ...createStringTagDescriptors("Temporal.Now"),
  ...createPropDescriptors({
    timeZoneId: () => getCurrentTimeZoneId(),
    instant: () => Mo(createInstantSlots(getCurrentEpochNanoseconds())),
    zonedDateTime: (e, n = getCurrentTimeZoneId()) => Po(createZonedDateTimeSlots(getCurrentEpochNanoseconds(), refineTimeZoneSlot(n), refineCalendarSlot(e))),
    zonedDateTimeISO: (e = getCurrentTimeZoneId()) => Po(createZonedDateTimeSlots(getCurrentEpochNanoseconds(), refineTimeZoneSlot(e), we)),
    plainDateTime: (e, n = getCurrentTimeZoneId()) => Yo(createPlainDateTimeSlots(getCurrentIsoDateTime(createSimpleTimeZoneOps(refineTimeZoneSlot(n))), refineCalendarSlot(e))),
    plainDateTimeISO: (e = getCurrentTimeZoneId()) => Yo(createPlainDateTimeSlots(getCurrentIsoDateTime(createSimpleTimeZoneOps(refineTimeZoneSlot(e))), we)),
    plainDate: (e, n = getCurrentTimeZoneId()) => Ro(createPlainDateSlots(getCurrentIsoDateTime(createSimpleTimeZoneOps(refineTimeZoneSlot(n))), refineCalendarSlot(e))),
    plainDateISO: (e = getCurrentTimeZoneId()) => Ro(createPlainDateSlots(getCurrentIsoDateTime(createSimpleTimeZoneOps(refineTimeZoneSlot(e))), we)),
    plainTimeISO: (e = getCurrentTimeZoneId()) => qo(createPlainTimeSlots(getCurrentIsoDateTime(createSimpleTimeZoneOps(refineTimeZoneSlot(e)))))
  })
}), Jo = Object.defineProperties({}, {
  ...createStringTagDescriptors("Temporal"),
  ...createPropDescriptors({
    PlainYearMonth: Jt,
    PlainMonthDay: Wt,
    PlainDate: Bo,
    PlainTime: jo,
    PlainDateTime: ko,
    ZonedDateTime: Oo,
    Instant: vo,
    Calendar: Go,
    TimeZone: So,
    Duration: Eo,
    Now: Ho
  })
});

export { DateTimeFormat as D, Jo as T, createPropDescriptors as c, toTemporalInstant as t };
